@@ -4,22 +4,33 @@ var group__js_assets_group =
     [ "jsPlacement_Init", "group__js_assets_group.html#ga223691e6831072a0b8f8103a778293b0", null ],
     [ "jsStreamSource_Init", "group__js_assets_group.html#ga7fe8e0bf98a38eb59372e7cd78aaaf56", null ],
     [ "jsExternalStream_Init", "group__js_assets_group.html#ga81aebebcd79922104720da51e95020d4", null ],
+    [ "jsRePublish_Init", "group__js_assets_group.html#ga388bfeaa5a78ebf6ce7c15c6e3a7156b", null ],
     [ "js_AddStream", "group__js_assets_group.html#ga5efc5136d33ba52161e6732f88f1ee75", null ],
     [ "js_UpdateStream", "group__js_assets_group.html#ga75a5c44304e24481c67e17fbccc15c31", null ],
     [ "js_PurgeStream", "group__js_assets_group.html#ga5a6a886c18a79caa403908bf7f7ef125", null ],
     [ "js_DeleteStream", "group__js_assets_group.html#ga397e55a0b3b6d36c9bf746eee3842172", null ],
     [ "js_GetMsg", "group__js_assets_group.html#ga9fe289ae172f83e53ca1b1b747744c1f", null ],
     [ "js_GetLastMsg", "group__js_assets_group.html#ga6835b53da27d5721eddb3698e582cf0c", null ],
+    [ "jsDirectGetMsgOptions_Init", "group__js_assets_group.html#ga8d835d47aed9c84ce3b8dcfea469f4cb", null ],
+    [ "js_DirectGetMsg", "group__js_assets_group.html#ga62c250cecc650b1eed0fa1691893e2ae", null ],
     [ "js_DeleteMsg", "group__js_assets_group.html#gaeba5d45abbe811c0e40830c5f26c78fd", null ],
     [ "js_EraseMsg", "group__js_assets_group.html#ga7158f73e183462e9a15e9802e1746ff0", null ],
     [ "js_GetStreamInfo", "group__js_assets_group.html#ga94cb23a35516b7779de28fcbb263180a", null ],
     [ "jsStreamInfo_Destroy", "group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd", null ],
+    [ "js_Streams", "group__js_assets_group.html#ga531d91de372f0dffb8d64abecf88b0c0", null ],
+    [ "jsStreamInfoList_Destroy", "group__js_assets_group.html#ga38cdcc339eb8976d23296b99aa37d629", null ],
+    [ "js_StreamNames", "group__js_assets_group.html#gac3dfc87863dbbb3c959ecde4bce905bc", null ],
+    [ "jsStreamNamesList_Destroy", "group__js_assets_group.html#gaf8644f281d4e24893a6a170b4f7faa65", null ],
     [ "jsConsumerConfig_Init", "group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66", null ],
     [ "js_AddConsumer", "group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115", null ],
     [ "js_UpdateConsumer", "group__js_assets_group.html#gad13ec256e24710bb237995814871e554", null ],
     [ "js_GetConsumerInfo", "group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23", null ],
     [ "js_DeleteConsumer", "group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490", null ],
     [ "jsConsumerInfo_Destroy", "group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088", null ],
+    [ "js_Consumers", "group__js_assets_group.html#gaf28097ede3e9ba9926fb00856e63ffd9", null ],
+    [ "jsConsumerInfoList_Destroy", "group__js_assets_group.html#ga421de40d8e91658353111c3f2ea90ec8", null ],
+    [ "js_ConsumerNames", "group__js_assets_group.html#ga690d19af55d12b82c8523d1861cef8d0", null ],
+    [ "jsConsumerNamesList_Destroy", "group__js_assets_group.html#ga2ced0d190131460bf4608ab893dffc50", null ],
     [ "js_GetAccountInfo", "group__js_assets_group.html#gac8965dcfc6b465fbc323aa552c606c46", null ],
     [ "jsAccountInfo_Destroy", "group__js_assets_group.html#ga7c8664b38fcce8497746367d35e5f60b", null ]
 ];
\ No newline at end of file
