@@ -10,6 +10,11 @@ var nats_8h =
     [ "JSMsgRollup", "nats_8h.html#a3938efee417dc67ff2bcf62f913f9054", null ],
     [ "JSMsgRollupSubject", "nats_8h.html#ad22dce8f66bae9b3e1027790d9c95c09", null ],
     [ "JSMsgRollupAll", "nats_8h.html#acc62d11b7e67fe3feb74acdfa4a6e8ac", null ],
+    [ "JSStream", "nats_8h.html#aa2f2c14de864839a2ff7ea34415d37e0", null ],
+    [ "JSSequence", "nats_8h.html#a1c0a11996b44abc16a4f444ee4c1cb94", null ],
+    [ "JSLastSequence", "nats_8h.html#ae18fb15ea8130a650e904e5153eb30d5", null ],
+    [ "JSTimeStamp", "nats_8h.html#a5525cb01f8b0aec73cb13f3276449e0e", null ],
+    [ "JSSubject", "nats_8h.html#a3776aa9985557f0c6e382b01d2e3f602", null ],
     [ "natsSock", "nats_8h.html#af798865ac824e5959987de0fe8d07383", null ],
     [ "natsConnection", "group__types_group.html#gaf88dca0a18efb5c5e994d265a9f04aec", null ],
     [ "natsStatistics", "group__types_group.html#ga57a4b8c7109e2773878655722ce028aa", null ],
@@ -23,6 +28,7 @@ var nats_8h =
     [ "jsPlacement", "group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9", null ],
     [ "jsExternalStream", "group__types_group.html#gaef6601477f6456bebc229f7f38982a6c", null ],
     [ "jsStreamSource", "group__types_group.html#gab4c43c87d81917aab748a50eee028449", null ],
+    [ "jsRePublish", "group__types_group.html#gab991313d33ce270a882e4d0756c138f6", null ],
     [ "jsStreamConfig", "group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf", null ],
     [ "jsLostStreamData", "group__types_group.html#gaf80828510450faf84bbf456e94f5b784", null ],
     [ "jsStreamStateSubject", "group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa", null ],
@@ -32,18 +38,25 @@ var nats_8h =
     [ "jsClusterInfo", "group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6", null ],
     [ "jsStreamSourceInfo", "group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd", null ],
     [ "jsStreamInfo", "group__types_group.html#ga2629c9454996edf7914be36a9e44921b", null ],
+    [ "jsStreamInfoList", "group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565", null ],
+    [ "jsStreamNamesList", "group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000", null ],
     [ "jsConsumerConfig", "group__types_group.html#ga0483b2197c0ddd9082b48c2dd3fe7cee", null ],
     [ "jsConsumerSequenceMismatch", "group__types_group.html#gace471cd2cef1df797b2a1c6b485049bd", null ],
     [ "jsSubOptions", "group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280", null ],
     [ "jsSequencePair", "group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f", null ],
     [ "jsSequenceInfo", "group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003", null ],
     [ "jsConsumerInfo", "group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5", null ],
+    [ "jsConsumerInfoList", "group__types_group.html#gadad3bf72baae970662248d82d9b05d0a", null ],
+    [ "jsConsumerNamesList", "group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2", null ],
     [ "jsAPIStats", "group__types_group.html#gad057a0107367ce5727975f3daf63ff75", null ],
     [ "jsAccountLimits", "group__types_group.html#gaa889f706cce285adb9cea8aba0b76866", null ],
+    [ "jsTier", "group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8", null ],
     [ "jsAccountInfo", "group__types_group.html#ga57cdc53b29a4fedb5a4140b6e64a4fab", null ],
     [ "jsMsgMetaData", "group__types_group.html#gace9595b1a5ce3f7a13670367fd293b4a", null ],
     [ "jsPubAck", "group__types_group.html#gaf1d5e436c5d41c5b9b96d84e3d2bc86f", null ],
     [ "jsPubAckErr", "group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40", null ],
+    [ "jsDirectGetMsgOptions", "group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063", null ],
+    [ "jsFetchRequest", "group__types_group.html#gaf11e6664c1f335a5287af71c703935fa", null ],
     [ "jsOptions", "group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5", null ],
     [ "kvStore", "group__types_group.html#ga054c05493dd3cfc5c3e7a665a424e54a", null ],
     [ "kvEntry", "group__types_group.html#gad489fb4074f27427560ca71797db6191", null ],
@@ -72,6 +85,7 @@ var nats_8h =
     [ "natsOnCompleteCB", "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a", null ],
     [ "natsCustomReconnectDelayHandler", "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4", null ],
     [ "jsPubAckErrHandler", "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992", null ],
+    [ "jsPubAckHandler", "group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729", null ],
     [ "stanPubAckHandler", "group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18", null ],
     [ "stanMsgHandler", "group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409", null ],
     [ "stanConnectionLostHandler", "group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c", null ],
@@ -165,6 +179,7 @@ var nats_8h =
     [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
     [ "natsOptions_SetReconnectedCB", "group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980", null ],
     [ "natsOptions_SetDiscoveredServersCB", "group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65", null ],
+    [ "natsOptions_SetIgnoreDiscoveredServers", "group__opts_group.html#ga7e4172084520708b8c9f28e73174461c", null ],
     [ "natsOptions_SetLameDuckModeCB", "group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc", null ],
     [ "natsOptions_SetEventLoop", "group__opts_group.html#gab09491bad908dedcb323c780280733ff", null ],
     [ "natsOptions_UseGlobalMessageDelivery", "group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c", null ],
@@ -272,6 +287,8 @@ var nats_8h =
     [ "natsSubscription_Unsubscribe", "group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba", null ],
     [ "natsSubscription_AutoUnsubscribe", "group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116", null ],
     [ "natsSubscription_QueuedMsgs", "group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254", null ],
+    [ "natsSubscription_GetID", "group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20", null ],
+    [ "natsSubscription_GetSubject", "group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432", null ],
     [ "natsSubscription_SetPendingLimits", "group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4", null ],
     [ "natsSubscription_GetPendingLimits", "group__sub_group.html#ga786bb458981274fe717f266bd3b96d96", null ],
     [ "natsSubscription_GetPending", "group__sub_group.html#gaca6262e2ef842caa701a9f233db72707", null ],
@@ -308,22 +325,33 @@ var nats_8h =
     [ "jsPlacement_Init", "group__js_assets_group.html#ga223691e6831072a0b8f8103a778293b0", null ],
     [ "jsStreamSource_Init", "group__js_assets_group.html#ga7fe8e0bf98a38eb59372e7cd78aaaf56", null ],
     [ "jsExternalStream_Init", "group__js_assets_group.html#ga81aebebcd79922104720da51e95020d4", null ],
+    [ "jsRePublish_Init", "group__js_assets_group.html#ga388bfeaa5a78ebf6ce7c15c6e3a7156b", null ],
     [ "js_AddStream", "group__js_assets_group.html#ga5efc5136d33ba52161e6732f88f1ee75", null ],
     [ "js_UpdateStream", "group__js_assets_group.html#ga75a5c44304e24481c67e17fbccc15c31", null ],
     [ "js_PurgeStream", "group__js_assets_group.html#ga5a6a886c18a79caa403908bf7f7ef125", null ],
     [ "js_DeleteStream", "group__js_assets_group.html#ga397e55a0b3b6d36c9bf746eee3842172", null ],
     [ "js_GetMsg", "group__js_assets_group.html#ga9fe289ae172f83e53ca1b1b747744c1f", null ],
     [ "js_GetLastMsg", "group__js_assets_group.html#ga6835b53da27d5721eddb3698e582cf0c", null ],
+    [ "jsDirectGetMsgOptions_Init", "group__js_assets_group.html#ga8d835d47aed9c84ce3b8dcfea469f4cb", null ],
+    [ "js_DirectGetMsg", "group__js_assets_group.html#ga62c250cecc650b1eed0fa1691893e2ae", null ],
     [ "js_DeleteMsg", "group__js_assets_group.html#gaeba5d45abbe811c0e40830c5f26c78fd", null ],
     [ "js_EraseMsg", "group__js_assets_group.html#ga7158f73e183462e9a15e9802e1746ff0", null ],
     [ "js_GetStreamInfo", "group__js_assets_group.html#ga94cb23a35516b7779de28fcbb263180a", null ],
     [ "jsStreamInfo_Destroy", "group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd", null ],
+    [ "js_Streams", "group__js_assets_group.html#ga531d91de372f0dffb8d64abecf88b0c0", null ],
+    [ "jsStreamInfoList_Destroy", "group__js_assets_group.html#ga38cdcc339eb8976d23296b99aa37d629", null ],
+    [ "js_StreamNames", "group__js_assets_group.html#gac3dfc87863dbbb3c959ecde4bce905bc", null ],
+    [ "jsStreamNamesList_Destroy", "group__js_assets_group.html#gaf8644f281d4e24893a6a170b4f7faa65", null ],
     [ "jsConsumerConfig_Init", "group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66", null ],
     [ "js_AddConsumer", "group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115", null ],
     [ "js_UpdateConsumer", "group__js_assets_group.html#gad13ec256e24710bb237995814871e554", null ],
     [ "js_GetConsumerInfo", "group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23", null ],
     [ "js_DeleteConsumer", "group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490", null ],
     [ "jsConsumerInfo_Destroy", "group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088", null ],
+    [ "js_Consumers", "group__js_assets_group.html#gaf28097ede3e9ba9926fb00856e63ffd9", null ],
+    [ "jsConsumerInfoList_Destroy", "group__js_assets_group.html#ga421de40d8e91658353111c3f2ea90ec8", null ],
+    [ "js_ConsumerNames", "group__js_assets_group.html#ga690d19af55d12b82c8523d1861cef8d0", null ],
+    [ "jsConsumerNamesList_Destroy", "group__js_assets_group.html#ga2ced0d190131460bf4608ab893dffc50", null ],
     [ "js_GetAccountInfo", "group__js_assets_group.html#gac8965dcfc6b465fbc323aa552c606c46", null ],
     [ "jsAccountInfo_Destroy", "group__js_assets_group.html#ga7c8664b38fcce8497746367d35e5f60b", null ],
     [ "jsPubOptions_Init", "group__js_pub_group.html#gaf09f333a8675a8060c5ede07a6bdeef9", null ],
@@ -339,6 +367,8 @@ var nats_8h =
     [ "js_SubscribeSync", "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf", null ],
     [ "js_PullSubscribe", "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd", null ],
     [ "natsSubscription_Fetch", "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50", null ],
+    [ "jsFetchRequest_Init", "group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b", null ],
+    [ "natsSubscription_FetchRequest", "group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed", null ],
     [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
     [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ],
     [ "natsMsg_GetMetaData", "group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328", null ],
