@@ -6,8 +6,46 @@ var NAVTREEINDEX0 =
 "dir_085924db4bed469054a9264cf96b0d5e.html":[4,0,0,0],
 "dir_68267d1309a1af8e8297ef4c3efbcdba.html":[4,0,0],
 "files.html":[4,0],
+"functions.html":[3,2,0,0],
 "functions.html":[3,2,0],
+"functions_b.html":[3,2,0,1],
+"functions_c.html":[3,2,0,2],
+"functions_d.html":[3,2,0,3],
+"functions_e.html":[3,2,0,4],
+"functions_f.html":[3,2,0,5],
+"functions_h.html":[3,2,0,6],
+"functions_i.html":[3,2,0,7],
+"functions_k.html":[3,2,0,8],
+"functions_l.html":[3,2,0,9],
+"functions_m.html":[3,2,0,10],
+"functions_n.html":[3,2,0,11],
+"functions_o.html":[3,2,0,12],
+"functions_p.html":[3,2,0,13],
+"functions_q.html":[3,2,0,14],
+"functions_r.html":[3,2,0,15],
+"functions_s.html":[3,2,0,16],
+"functions_t.html":[3,2,0,17],
 "functions_vars.html":[3,2,1],
+"functions_vars.html":[3,2,1,0],
+"functions_vars_b.html":[3,2,1,1],
+"functions_vars_c.html":[3,2,1,2],
+"functions_vars_d.html":[3,2,1,3],
+"functions_vars_e.html":[3,2,1,4],
+"functions_vars_f.html":[3,2,1,5],
+"functions_vars_h.html":[3,2,1,6],
+"functions_vars_i.html":[3,2,1,7],
+"functions_vars_k.html":[3,2,1,8],
+"functions_vars_l.html":[3,2,1,9],
+"functions_vars_m.html":[3,2,1,10],
+"functions_vars_n.html":[3,2,1,11],
+"functions_vars_o.html":[3,2,1,12],
+"functions_vars_p.html":[3,2,1,13],
+"functions_vars_q.html":[3,2,1,14],
+"functions_vars_r.html":[3,2,1,15],
+"functions_vars_s.html":[3,2,1,16],
+"functions_vars_t.html":[3,2,1,17],
+"functions_vars_w.html":[3,2,1,18],
+"functions_w.html":[3,2,0,18],
 "globals.html":[4,1,0],
 "globals.html":[4,1,0,0],
 "globals_defs.html":[4,1,5],
@@ -29,16 +67,17 @@ var NAVTREEINDEX0 =
 "group__callbacks_group.html#ga2bb5dd2d821ca5bbc0488f7e6aceed17":[2,1,5],
 "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4":[2,1,11],
 "group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499":[2,1,9],
+"group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729":[2,1,13],
 "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992":[2,1,12],
 "group__callbacks_group.html#ga9e511dffa471dfb971b7dd2b12329626":[2,1,2],
 "group__callbacks_group.html#gab63dee7f7012ba11ae20b76dbc36f2d0":[2,1,6],
 "group__callbacks_group.html#gab786ffd670c86de0563559351305080b":[2,1,8],
-"group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c":[2,1,15],
+"group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c":[2,1,16],
 "group__callbacks_group.html#gacdef6aff3e47953f19e35857ab8e274c":[2,1,1],
 "group__callbacks_group.html#gad1a5ac566893e13dc8c81ac0e9c87afe":[2,1,0],
-"group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18":[2,1,13],
+"group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18":[2,1,14],
 "group__callbacks_group.html#gaea4c125ecfb43eaf43da20e8444c2aaa":[2,1,4],
-"group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409":[2,1,14],
+"group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409":[2,1,15],
 "group__conn_group.html":[2,2,9],
 "group__conn_mgt_group.html":[2,2,9,0],
 "group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5":[2,2,9,0,8],
@@ -92,27 +131,38 @@ var NAVTREEINDEX0 =
 "group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe":[2,2,6,1],
 "group__js_assets_group.html":[2,2,13,0],
 "group__js_assets_group.html#ga223691e6831072a0b8f8103a778293b0":[2,2,13,0,1],
-"group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23":[2,2,13,0,17],
-"group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66":[2,2,13,0,14],
-"group__js_assets_group.html#ga397e55a0b3b6d36c9bf746eee3842172":[2,2,13,0,7],
-"group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490":[2,2,13,0,18],
-"group__js_assets_group.html#ga5a6a886c18a79caa403908bf7f7ef125":[2,2,13,0,6],
-"group__js_assets_group.html#ga5efc5136d33ba52161e6732f88f1ee75":[2,2,13,0,4],
-"group__js_assets_group.html#ga6835b53da27d5721eddb3698e582cf0c":[2,2,13,0,9],
-"group__js_assets_group.html#ga7158f73e183462e9a15e9802e1746ff0":[2,2,13,0,11],
-"group__js_assets_group.html#ga75a5c44304e24481c67e17fbccc15c31":[2,2,13,0,5],
-"group__js_assets_group.html#ga7c8664b38fcce8497746367d35e5f60b":[2,2,13,0,21],
+"group__js_assets_group.html#ga2ced0d190131460bf4608ab893dffc50":[2,2,13,0,30],
+"group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23":[2,2,13,0,24],
+"group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66":[2,2,13,0,21],
+"group__js_assets_group.html#ga388bfeaa5a78ebf6ce7c15c6e3a7156b":[2,2,13,0,4],
+"group__js_assets_group.html#ga38cdcc339eb8976d23296b99aa37d629":[2,2,13,0,18],
+"group__js_assets_group.html#ga397e55a0b3b6d36c9bf746eee3842172":[2,2,13,0,8],
+"group__js_assets_group.html#ga421de40d8e91658353111c3f2ea90ec8":[2,2,13,0,28],
+"group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490":[2,2,13,0,25],
+"group__js_assets_group.html#ga531d91de372f0dffb8d64abecf88b0c0":[2,2,13,0,17],
+"group__js_assets_group.html#ga5a6a886c18a79caa403908bf7f7ef125":[2,2,13,0,7],
+"group__js_assets_group.html#ga5efc5136d33ba52161e6732f88f1ee75":[2,2,13,0,5],
+"group__js_assets_group.html#ga62c250cecc650b1eed0fa1691893e2ae":[2,2,13,0,12],
+"group__js_assets_group.html#ga6835b53da27d5721eddb3698e582cf0c":[2,2,13,0,10],
+"group__js_assets_group.html#ga690d19af55d12b82c8523d1861cef8d0":[2,2,13,0,29],
+"group__js_assets_group.html#ga7158f73e183462e9a15e9802e1746ff0":[2,2,13,0,14],
+"group__js_assets_group.html#ga75a5c44304e24481c67e17fbccc15c31":[2,2,13,0,6],
+"group__js_assets_group.html#ga7c8664b38fcce8497746367d35e5f60b":[2,2,13,0,32],
 "group__js_assets_group.html#ga7fe8e0bf98a38eb59372e7cd78aaaf56":[2,2,13,0,2],
 "group__js_assets_group.html#ga81aebebcd79922104720da51e95020d4":[2,2,13,0,3],
-"group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd":[2,2,13,0,13],
-"group__js_assets_group.html#ga94cb23a35516b7779de28fcbb263180a":[2,2,13,0,12],
-"group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088":[2,2,13,0,19],
-"group__js_assets_group.html#ga9fe289ae172f83e53ca1b1b747744c1f":[2,2,13,0,8],
+"group__js_assets_group.html#ga8d835d47aed9c84ce3b8dcfea469f4cb":[2,2,13,0,11],
+"group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd":[2,2,13,0,16],
+"group__js_assets_group.html#ga94cb23a35516b7779de28fcbb263180a":[2,2,13,0,15],
+"group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088":[2,2,13,0,26],
+"group__js_assets_group.html#ga9fe289ae172f83e53ca1b1b747744c1f":[2,2,13,0,9],
 "group__js_assets_group.html#gac230f71dbdc4d10bc7471d01763881d6":[2,2,13,0,0],
-"group__js_assets_group.html#gac8965dcfc6b465fbc323aa552c606c46":[2,2,13,0,20],
-"group__js_assets_group.html#gad13ec256e24710bb237995814871e554":[2,2,13,0,16],
-"group__js_assets_group.html#gaeba5d45abbe811c0e40830c5f26c78fd":[2,2,13,0,10],
-"group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115":[2,2,13,0,15],
+"group__js_assets_group.html#gac3dfc87863dbbb3c959ecde4bce905bc":[2,2,13,0,19],
+"group__js_assets_group.html#gac8965dcfc6b465fbc323aa552c606c46":[2,2,13,0,31],
+"group__js_assets_group.html#gad13ec256e24710bb237995814871e554":[2,2,13,0,23],
+"group__js_assets_group.html#gaeba5d45abbe811c0e40830c5f26c78fd":[2,2,13,0,13],
+"group__js_assets_group.html#gaf28097ede3e9ba9926fb00856e63ffd9":[2,2,13,0,27],
+"group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115":[2,2,13,0,22],
+"group__js_assets_group.html#gaf8644f281d4e24893a6a170b4f7faa65":[2,2,13,0,20],
 "group__js_group.html":[2,2,13],
 "group__js_group.html#ga855ff9a04888d696785cc5ede96112e4":[2,2,13,4],
 "group__js_group.html#ga8ed08b0fe1074b1e490291f0af2cb03f":[2,2,13,5],
@@ -138,10 +188,12 @@ var NAVTREEINDEX0 =
 "group__js_pub_group.html#gac6ba005531c82d9f0efa88dd6b458477":[2,2,13,1,1],
 "group__js_pub_group.html#gaf09f333a8675a8060c5ede07a6bdeef9":[2,2,13,1,0],
 "group__js_sub_group.html":[2,2,13,2],
-"group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84":[2,2,13,2,6],
+"group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84":[2,2,13,2,8],
+"group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b":[2,2,13,2,5],
 "group__js_sub_group.html#ga472adb949d1af9d8f07bda99f5d7f3f8":[2,2,13,2,0],
+"group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed":[2,2,13,2,6],
 "group__js_sub_group.html#gaa686c6efd84ef963de1925108e896515":[2,2,13,2,1],
-"group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e":[2,2,13,2,5],
+"group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e":[2,2,13,2,7],
 "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd":[2,2,13,2,3],
 "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf":[2,2,13,2,2],
 "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50":[2,2,13,2,4],
@@ -197,57 +249,5 @@ var NAVTREEINDEX0 =
 "group__kv_watcher.html#ga73adf44114fedd62ef75ebd81839b65e":[2,2,14,2,1],
 "group__libevent_functions.html":[2,5],
 "group__libevent_functions.html#ga195d269473332931fd0fede0bac3309e":[2,5,0],
-"group__libevent_functions.html#ga30c00f21a5251ee9fde09c1f2b429cd2":[2,5,1],
-"group__libevent_functions.html#ga7ac99f326a59e5663ff66f5023c87091":[2,5,3],
-"group__libevent_functions.html#ga8a14ce23b4f6ba3bf63369961f9a5552":[2,5,2],
-"group__libevent_functions.html#gaac76f5937329a8650f69c6bd8af36cd5":[2,5,4],
-"group__library_group.html":[2,2,0],
-"group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8":[2,2,0,1],
-"group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d":[2,2,0,0],
-"group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4":[2,2,0,9],
-"group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8":[2,2,0,2],
-"group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e":[2,2,0,3],
-"group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e":[2,2,0,4],
-"group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d":[2,2,0,10],
-"group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e":[2,2,0,8],
-"group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223":[2,2,0,5],
-"group__library_group.html#gad5040264cd4b1404956babf3c03a4f09":[2,2,0,6],
-"group__library_group.html#gadecfd49a58b581dbba40da77b195fd85":[2,2,0,7],
-"group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e":[2,2,0,13],
-"group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903":[2,2,0,14],
-"group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba":[2,2,0,12],
-"group__library_group.html#gafe171baefa00a85b77205116e9f3e48a":[2,2,0,11],
-"group__libuv_functions.html":[2,6],
-"group__libuv_functions.html#ga1baf4a20b138dcf00807a8b830f4e02d":[2,6,1],
-"group__libuv_functions.html#ga5d4b677cbe1cd132c37bc56dbfc6949e":[2,6,0],
-"group__libuv_functions.html#ga85c722b2d2699a954362b20528f0aaac":[2,6,3],
-"group__libuv_functions.html#ga86ac71cffe752effd7397740d80c3c42":[2,6,2],
-"group__libuv_functions.html#ga8df663525fb59b882a0f3bd563083dc7":[2,6,5],
-"group__libuv_functions.html#gafaa633c9067f485f330b72644277b07d":[2,6,4],
-"group__msg_group.html":[2,2,7],
-"group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21":[2,2,7,1],
-"group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2":[2,2,7,0],
-"group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de":[2,2,7,5],
-"group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b":[2,2,7,7],
-"group__msg_group.html#ga43aa4a8e4b93725b4876ee2677e19c7b":[2,2,7,12],
-"group__msg_group.html#ga523364451fd92534e754054266196e59":[2,2,7,4],
-"group__msg_group.html#ga6ee8a007111ada293dd24ff0bab02491":[2,2,7,10],
-"group__msg_group.html#ga880535362c91b3e405792aa66ff945b6":[2,2,7,3],
-"group__msg_group.html#ga9e9590018284939f43f60964283f33ae":[2,2,7,13],
-"group__msg_group.html#gab3349f0b0ce721b340d5c0753c90ee18":[2,2,7,8],
-"group__msg_group.html#gac78ca02dc93d05cae837ced6386408f1":[2,2,7,11],
-"group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a":[2,2,7,2],
-"group__msg_group.html#gae1ce9c9d82d151a3ea9dc03da048f66f":[2,2,7,9],
-"group__msg_group.html#gaf30b47d4217c9335919f05536e379af8":[2,2,7,6],
-"group__opts_group.html":[2,2,3],
-"group__opts_group.html#ga0290eac4665569c850468d9f00e246a0":[2,2,3,46],
-"group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851":[2,2,3,16],
-"group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd":[2,2,3,30],
-"group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9":[2,2,3,7],
-"group__opts_group.html#ga192465163abb87ad48a843b45cdf9984":[2,2,3,49],
-"group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3":[2,2,3,22],
-"group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e":[2,2,3,8],
-"group__opts_group.html#ga20946800d024b7089e73d63454d1c19f":[2,2,3,43],
-"group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426":[2,2,3,5],
-"group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980":[2,2,3,33]
+"group__libevent_functions.html#ga30c00f21a5251ee9fde09c1f2b429cd2":[2,5,1]
 };
