@@ -1,5 +1,74 @@
 var NAVTREEINDEX2 =
 {
+"group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a2c4a1e2b75f31dd69a89b541d75afa44":[2,0,101,0],
+"group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a6ee3851dac5c90a61492193dd55931f5":[2,0,101,1],
+"group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a0b7a6bef67e4220f5f0c4075f2ed16b6":[2,0,102,0],
+"group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a4efb91331f3307128c75af5b23362f83":[2,0,102,2],
+"group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332acc0e1da3c292cb7eb19d909c9dfd788a":[2,0,102,1],
+"group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332aee19ab8144bf518e251ea2004309b657":[2,0,102,3],
+"group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a02d46a6395933c55c95ee5194bb6b80e":[2,0,100,0],
+"group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a1232af28bf4e4b82e962174f1432ed4a":[2,0,100,2],
+"group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873afd91fe31cf57c68863ca3090b07c296c":[2,0,100,1],
+"group__wildcards_group.html":[2,3],
+"index.html":[],
+"index.html":[0],
+"index.html#faq_sec":[0,2],
+"index.html#install_sec":[0,1],
+"index.html#intro_sec":[0,0],
+"index.html#other_doc_section":[0,3],
+"libevent_8h.html":[4,0,0,0,0],
+"libevent_8h_source.html":[4,0,0,0,0],
+"libuv_8h.html":[4,0,0,0,1],
+"libuv_8h_source.html":[4,0,0,0,1],
+"modules.html":[2],
+"nats_8h.html":[4,0,0,1],
+"nats_8h.html#a1c0a11996b44abc16a4f444ee4c1cb94":[4,0,0,1,11],
+"nats_8h.html#a3776aa9985557f0c6e382b01d2e3f602":[4,0,0,1,14],
+"nats_8h.html#a3938efee417dc67ff2bcf62f913f9054":[4,0,0,1,7],
+"nats_8h.html#a3bc1b3fe7f64083e60c7c3b93f205bad":[4,0,0,1,4],
+"nats_8h.html#a5525cb01f8b0aec73cb13f3276449e0e":[4,0,0,1,13],
+"nats_8h.html#a5ce9005964bd9cf0604a9ef1afa87ea4":[4,0,0,1,6],
+"nats_8h.html#a911c54900b46b968205871cd9f68d36c":[4,0,0,1,5],
+"nats_8h.html#aa2f2c14de864839a2ff7ea34415d37e0":[4,0,0,1,10],
+"nats_8h.html#acc62d11b7e67fe3feb74acdfa4a6e8ac":[4,0,0,1,9],
+"nats_8h.html#ad22dce8f66bae9b3e1027790d9c95c09":[4,0,0,1,8],
+"nats_8h.html#ae18fb15ea8130a650e904e5153eb30d5":[4,0,0,1,12],
+"nats_8h.html#af798865ac824e5959987de0fe8d07383":[4,0,0,1,15],
+"nats_8h_source.html":[4,0,0,1],
+"pages.html":[],
+"status_8h.html":[4,0,0,2],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70":[4,0,0,2,2],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a00b4ce854e473bb8f49d91c0f982c6f9":[4,0,0,2,2,98],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a02a521ae52b716a669a3556d63a21410":[4,0,0,2,2,35],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a051bfd5e3bb9ba2b2398e6501426bc63":[4,0,0,2,2,103],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a0c34c56b62e4246560efabd5c762aa03":[4,0,0,2,2,50],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a0dc0fcc88a8b39f03924d50ccf731043":[4,0,0,2,2,32],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a0f2007fc94103909ece328bbd77b0cdb":[4,0,0,2,2,91],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a1381bb653998c6ca8b88002d0fe0c829":[4,0,0,2,2,18],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a17c212f9409e4bd9db060bd2796905e4":[4,0,0,2,2,15],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a1d159f128cd9b261b5270f7e36ed22d1":[4,0,0,2,2,123],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a1eaa16332bbe6cb041adbb60383f944c":[4,0,0,2,2,41],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a1efc26df606f855cfb9993cbe95c0f46":[4,0,0,2,2,64],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a2107facbac830a905217916c7d24297a":[4,0,0,2,2,46],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a26a33a6e2296eb0ac0370176fb08ed9a":[4,0,0,2,2,0],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a27579bca64e6f40f9590ef51ac03a219":[4,0,0,2,2,85],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a2984e6b8850b6cfed9506a25bcbe0608":[4,0,0,2,2,101],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a2a8844e5d20c55d753ec64bbde4561c8":[4,0,0,2,2,84],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a2f4ee662c9cbaa0355c52de1c2463160":[4,0,0,2,2,45],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a32546264d1f24fc9dafe490212bfd893":[4,0,0,2,2,7],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a33f2e301313339eded6163982a680186":[4,0,0,2,2,107],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a3552ffc73e39c13d14ae35f52cd3ead7":[4,0,0,2,2,66],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a3799b98b675eeca3403a1728bd0cd5f8":[4,0,0,2,2,19],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a3b1ce6536b249952dc3fb6fe5448140f":[4,0,0,2,2,99],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a3e55a221685d96d96c514d6d5c652570":[4,0,0,2,2,63],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a407efbf6c688cb93fcded08acd2a08ed":[4,0,0,2,2,83],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a429a21189134500589ed67ac3701aff4":[4,0,0,2,2,80],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a46321fc22a103908324b72259832af60":[4,0,0,2,2,8],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4712c1322585d712cef9b67cd03a3e00":[4,0,0,2,2,77],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a475581c5dfbabb52334ce28013382b58":[4,0,0,2,2,67],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4963c5ecd065d3e336daf80a7cd1aa57":[4,0,0,2,2,40],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4a95591dfc0e2ccb1d3ac1b3a04f618f":[4,0,0,2,2,76],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4ae7ffdfb53fb238a76ebe19c7482696":[4,0,0,2,2,6],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4d68fa855750f16fdf38c9ed93acacda":[4,0,0,2,2,73],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4ef7a2042b48d5e0916e7e90fe691ab3":[4,0,0,2,2,17],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a4f192c39f1d7244ceb639053fad86393":[4,0,0,2,2,51],
@@ -9,9 +78,12 @@ var NAVTREEINDEX2 =
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a519d32e9718662347753ebffaf731889":[4,0,0,2,2,52],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a54084c4f82593cf516cd604b34c0dce8":[4,0,0,2,2,53],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a557d48b0334c5ceec0f0ee7cc74d8e79":[4,0,0,2,2,87],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a584d0bf058191cf2257d934f0bc5935c":[4,0,0,2,2,120],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a58db02b3e72f3b20300344f97c5c7b34":[4,0,0,2,2,59],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a597c98a0637cec454b724b049098cee8":[4,0,0,2,2,122],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a5f7b670b9202311da41e6e5026e810d2":[4,0,0,2,2,97],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a600ddc1915d8bb928fd37f1539440eb3":[4,0,0,2,2,30],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a60fd558fc8d0f31b895c7b579ba0c8b7":[4,0,0,2,2,119],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a6181f797cb27c92473585893b92b95b0":[4,0,0,2,2,89],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a61cd7aa9b9e02f410465a61a085fa209":[4,0,0,2,2,110],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a64dbcba923d50e6f258db59b85eb8b17":[4,0,0,2,2,61],
@@ -25,6 +97,7 @@ var NAVTREEINDEX2 =
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a7a89433d532a863561087229b19a525f":[4,0,0,2,2,22],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a7adbc8c115996a6f0dfc98fcaac8f09d":[4,0,0,2,2,96],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a7b5cebb5aaebd7b3bfa43f5457e97553":[4,0,0,2,2,114],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a7c88e5ccabcb2debe1ce0c1a05bbe18b":[4,0,0,2,2,115],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a801182af5b4a6b9547d81ec45864b1f3":[4,0,0,2,2,92],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a80d0a9f218207a11b4cc19b9c2aec83f":[4,0,0,2,2,54],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a84864e4bba24ee7354e5bae293c93d00":[4,0,0,2,2,34],
@@ -45,6 +118,7 @@ var NAVTREEINDEX2 =
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70a9eef13e3281a879f36a30e246fb6021b":[4,0,0,2,2,12],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa023de74e8bedf88c2f5e4b21e62ea4b":[4,0,0,2,2,39],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa0ca5a2e539cec9d33f433f28f2780fe":[4,0,0,2,2,100],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa0eb191886a17e917f2fa0eaa81d4b61":[4,0,0,2,2,116],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa1242d9e6509f08c01c3373d0e66dc96":[4,0,0,2,2,109],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa1b904de1494d20f540c8075f502af24":[4,0,0,2,2,24],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70aa88122abfaf173f0411a3642803aac04":[4,0,0,2,2,37],
@@ -62,9 +136,12 @@ var NAVTREEINDEX2 =
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70abc4bf9a7703ef8d3fbf2b1ad2ece3717":[4,0,0,2,2,49],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70abca8571110c4244d218c2dc1779d8786":[4,0,0,2,2,111],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70abd3f17c5d6ea86c38c3d8ade18b8445a":[4,0,0,2,2,82],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70abf7739c7a0569149ed24ae8b9fbaf889":[4,0,0,2,2,121],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ac3d700ce84bc5df96c383079b093cc45":[4,0,0,2,2,62],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ac4afe1d580083bd55c36b3e55a5ef479":[4,0,0,2,2,118],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ac75e39643f73b184b22330939c4a564e":[4,0,0,2,2,44],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70acedca75c7ec69c5573da7013f69ede13":[4,0,0,2,2,1],
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70acfa2c06f8baef07cd96a3627ddea641b":[4,0,0,2,2,117],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ad07006ca41165d13442df8e62ef3f398":[4,0,0,2,2,70],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ad1ec102705e46b5343c2680162f58f49":[4,0,0,2,2,21],
 "status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70adc58d142e277166a57672812df6f2c3e":[4,0,0,2,2,68],
@@ -132,122 +209,45 @@ var NAVTREEINDEX2 =
 "status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51ac6b8b7f138f6ca285fe1f4da707b2100":[4,0,0,2,0,6],
 "status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51acfdc4826e08ce4b59f901952038e9206":[4,0,0,2,0,4],
 "status_8h_source.html":[4,0,0,2],
-"structjs_a_p_i_stats.html":[2,0,20],
-"structjs_a_p_i_stats.html#a1545170bebb347d0ea1254f51c3027cf":[2,0,20,0],
-"structjs_a_p_i_stats.html#a84e85ad9d94dbe9afd1101388574255d":[2,0,20,1],
-"structjs_account_info.html":[2,0,22],
-"structjs_account_info.html#a1237c3f19a42a3203825971b429312e9":[2,0,22,3],
-"structjs_account_info.html#a17317abf03effdcdedc2003fca8adc71":[2,0,22,2],
-"structjs_account_info.html#a448578d621e878267ad5f1792002a665":[2,0,22,0],
-"structjs_account_info.html#a94ab71c69b7883c2731ae8741ddc1e94":[2,0,22,5],
-"structjs_account_info.html#aad93cf4bb6c1fbb09ae8545c03f315a9":[2,0,22,6],
-"structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c":[2,0,22,4],
-"structjs_account_info.html#ad1c254c5b8f11f57062a4e2d5fb10ae3":[2,0,22,1],
-"structjs_account_limits.html":[2,0,21],
-"structjs_account_limits.html#a4710a10950857a322c2a3ad6f946ded2":[2,0,21,2],
-"structjs_account_limits.html#a6169f29101d51d48eed0803b719e6338":[2,0,21,3],
-"structjs_account_limits.html#a6fff014c46739410ecf298b0cf643b30":[2,0,21,1],
-"structjs_account_limits.html#a7bfc63e6f49ce724663ee534c5efdfa4":[2,0,21,0],
-"structjs_cluster_info.html":[2,0,11],
-"structjs_cluster_info.html#a237a639579def1345e02f1490a510ed5":[2,0,11,3],
-"structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484":[2,0,11,0],
-"structjs_cluster_info.html#a8dfcae3bc348a5b595b509e3f3d3500b":[2,0,11,2],
-"structjs_cluster_info.html#af7d85652b52f56fa1eedce8f45fe6a19":[2,0,11,1],
-"structjs_consumer_config.html":[2,0,14],
-"structjs_consumer_config.html#a2f0243899885dc97f304f48ca52b5356":[2,0,14,5],
-"structjs_consumer_config.html#a30d4142bac47ab6dc583c5ee193704e6":[2,0,14,20],
-"structjs_consumer_config.html#a351b388a36ccb7978e6e85a6f4fc0816":[2,0,14,14],
-"structjs_consumer_config.html#a364127e68bf0d3bf13efdc0b416667f4":[2,0,14,4],
-"structjs_consumer_config.html#a36a14d666d99bdade87a5e21a25491d6":[2,0,14,1],
-"structjs_consumer_config.html#a36cf121162cf0b40edf051991d851ee0":[2,0,14,0],
-"structjs_consumer_config.html#a43f40b8eef0074b4146fb945b4645584":[2,0,14,15],
-"structjs_consumer_config.html#a484c64b6c54f6f758f54315470ed20d0":[2,0,14,18],
-"structjs_consumer_config.html#a4e86deefe08854b9a82b4908397aad32":[2,0,14,21],
-"structjs_consumer_config.html#a651a94b9b78668dde830dc7869610e67":[2,0,14,8],
-"structjs_consumer_config.html#a802ea3bf0669395bee28611f4ecede80":[2,0,14,6],
-"structjs_consumer_config.html#a8472d49fae908ab0291b4d62c8411b76":[2,0,14,16],
-"structjs_consumer_config.html#a8a311af614dfae1b0f4e4af7db467aab":[2,0,14,7],
-"structjs_consumer_config.html#a95aa4184ed77f69b7674756572da1ded":[2,0,14,2],
-"structjs_consumer_config.html#aa2d0aff64a2c46122d0f0fe89e8ae011":[2,0,14,10],
-"structjs_consumer_config.html#aa71aa3dfe5826466be301097b1bae04d":[2,0,14,22],
-"structjs_consumer_config.html#ac439828c3bedb8826a1e92de13280d53":[2,0,14,19],
-"structjs_consumer_config.html#ad2f6ca3f2d0f977aedb8687c462c1cfc":[2,0,14,11],
-"structjs_consumer_config.html#ad47e15e1d6a4a8b0b155f9d3d5873c95":[2,0,14,9],
-"structjs_consumer_config.html#ade510daf7c5d67553d2cd20b64ab9939":[2,0,14,13],
-"structjs_consumer_config.html#ae0765f3b5effe365187d3cf809c6ed3c":[2,0,14,3],
-"structjs_consumer_config.html#aeb2336d480e3885385d1b08410e89892":[2,0,14,17],
-"structjs_consumer_config.html#af56ab7708b11e85e0b9115d152d281ca":[2,0,14,12],
-"structjs_consumer_config.html#af6376a6009124c25d7016bc548f3855d":[2,0,14,23],
-"structjs_consumer_info.html":[2,0,19],
-"structjs_consumer_info.html#a15f2d68fbf126acc1907ba9462ad9ee9":[2,0,19,4],
-"structjs_consumer_info.html#a2f63940ca1f024ad3840418c2f6a1ae1":[2,0,19,3],
-"structjs_consumer_info.html#a31282cdc72000a91af03f89899740bfa":[2,0,19,11],
-"structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0":[2,0,19,8],
-"structjs_consumer_info.html#a670d38f2e9ba5c354ca3560a8064d00c":[2,0,19,2],
-"structjs_consumer_info.html#a6f4401563a9fd102226d82cdc6136e32":[2,0,19,10],
-"structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50":[2,0,19,6],
-"structjs_consumer_info.html#a8f21939613163a7c0ebfb521aa471260":[2,0,19,0],
-"structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001":[2,0,19,7],
-"structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008":[2,0,19,1],
-"structjs_consumer_info.html#ab69c36ae092df9b0663b675a5abbab55":[2,0,19,5],
-"structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b":[2,0,19,9],
-"structjs_consumer_sequence_mismatch.html":[2,0,15],
-"structjs_consumer_sequence_mismatch.html#aad6a17af1719c023c38a6fd254b73f8e":[2,0,15,0],
-"structjs_consumer_sequence_mismatch.html#ac1df353001d853c8a56cef9f82fb831c":[2,0,15,2],
-"structjs_consumer_sequence_mismatch.html#adb383429dadb1ab0e1f7d013bc546a28":[2,0,15,1],
-"structjs_external_stream.html":[2,0,3],
-"structjs_external_stream.html#a26ca427f3c5be1cae579ddccc16432d3":[2,0,3,1],
-"structjs_external_stream.html#a2eaf2c0c3e77c269f44e254af8b24e96":[2,0,3,0],
-"structjs_lost_stream_data.html":[2,0,6],
-"structjs_lost_stream_data.html#a5d2e87697526033c842a7f955776dfda":[2,0,6,0],
-"structjs_lost_stream_data.html#a841fcadca3f66e9170a51080dc1acf30":[2,0,6,2],
-"structjs_lost_stream_data.html#abdc373ed7fc9b7cf161c13da1913fc9a":[2,0,6,1],
-"structjs_msg_meta_data.html":[2,0,23],
-"structjs_msg_meta_data.html#a02f1bbd37e9650ed6bfda0210f038e30":[2,0,23,2],
-"structjs_msg_meta_data.html#a23d5fd1992033164c73d5c2a16a4e321":[2,0,23,0],
-"structjs_msg_meta_data.html#a32e2a9438d2dc769f7f64d2f8897abc4":[2,0,23,4],
-"structjs_msg_meta_data.html#a388e38ccea591181436d199dc7c2f8ea":[2,0,23,6],
-"structjs_msg_meta_data.html#a6dcc2a442984b0ca070b3d8077192127":[2,0,23,5],
-"structjs_msg_meta_data.html#a9a50965fac061a9728b160702d3f56ff":[2,0,23,1],
-"structjs_msg_meta_data.html#abab9ed5600a3629ea6d6c78170d7d5e9":[2,0,23,3],
-"structjs_options.html":[2,0,26],
-"structjs_options.html#a5ce5c11cc9b9df2b6bc47cd77d7b1dc4":[2,0,26,5],
-"structjs_options.html#a7fd42e1f83da5861e716137c16f8b72f":[2,0,26,4],
-"structjs_options.html#ab06e45296fccf0fe6152e083e38d916f":[2,0,26,2],
-"structjs_options.html#ae4df6c9c01c0ea9ab0e6d5a6ec8af74e":[2,0,26,3],
-"structjs_options.html#ae50544ee0ef8dd7d02ef9802805807ae":[2,0,26,6],
-"structjs_options_1_1js_options_publish_async.html":[2,0,26,0],
-"structjs_options_1_1js_options_publish_async.html#a0a180995c49990ca277e449b7d43616b":[2,0,26,0,1],
-"structjs_options_1_1js_options_publish_async.html#a784a0029c30e82ff37c39ae6c276bc81":[2,0,26,0,2],
-"structjs_options_1_1js_options_publish_async.html#ada58fefe0ed40157b5f5d44b9dd175f9":[2,0,26,0,3],
-"structjs_options_1_1js_options_publish_async.html#add8dd21cbab2d5df19688c26365fe4d1":[2,0,26,0,0],
-"structjs_options_1_1js_options_stream.html":[2,0,26,1],
-"structjs_options_1_1js_options_stream.html#a2ca89c298b4df1f5e3e0a44e205c789c":[2,0,26,1,3],
-"structjs_options_1_1js_options_stream.html#afe680264223b434ca6959f9e122af029":[2,0,26,1,2],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_info.html":[2,0,26,1,0],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_info.html#a73f847afe18f56eaaf6788900270bef7":[2,0,26,1,0,0],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_info.html#af874e0f5aa15fb2a41504631ed786e6d":[2,0,26,1,0,1],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html":[2,0,26,1,1],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a0d61e5d3c9c518f455549086ababe7f6":[2,0,26,1,1,1],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a882c1ce1e636817450893caa72aa4eda":[2,0,26,1,1,2],
-"structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#aa99e6ee3bef1c22243f01544181315fe":[2,0,26,1,1,0],
-"structjs_peer_info.html":[2,0,10],
-"structjs_peer_info.html#a3f3e09c5996858ec5faca2dc7fa5224e":[2,0,10,2],
-"structjs_peer_info.html#a49a2623963dad653a6d7996c750056c9":[2,0,10,4],
-"structjs_peer_info.html#a8441d023932c388953197f7ea39402fe":[2,0,10,3],
-"structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a":[2,0,10,0],
-"structjs_peer_info.html#ad8cecd039a8ad1c68daba89007b055d4":[2,0,10,1],
-"structjs_placement.html":[2,0,2],
-"structjs_placement.html#a35644f07531409518521b1b4fa28c9e3":[2,0,2,2],
-"structjs_placement.html#ad8c83588d57f0e30959cfb6f3d5d61bf":[2,0,2,0],
-"structjs_placement.html#af078a85b744b9ff3771bb2da6005b90d":[2,0,2,1],
-"structjs_pub_ack.html":[2,0,24],
-"structjs_pub_ack.html#a01d302d5e1a2e71487a8c74c3fed1691":[2,0,24,1],
-"structjs_pub_ack.html#a0381a49ff62e8fac7a52cad6a5eb7243":[2,0,24,3],
-"structjs_pub_ack.html#a0b73200c0b035db3c9c96421706d51b0":[2,0,24,2],
-"structjs_pub_ack.html#a4fd5e6cdb7217d72c553afcc75358893":[2,0,24,0],
-"structjs_pub_ack_err.html":[2,0,25],
-"structjs_pub_ack_err.html#a156ca2f779d132ffa8c519124cf9739b":[2,0,25,0],
-"structjs_pub_ack_err.html#a406e39e818f93bc59ac18cbdf035baf5":[2,0,25,1],
-"structjs_pub_ack_err.html#aa558fd192cc6d6c02ad891445ec5aa8a":[2,0,25,2]
+"structjs_a_p_i_stats.html":[2,0,25],
+"structjs_a_p_i_stats.html#a1545170bebb347d0ea1254f51c3027cf":[2,0,25,0],
+"structjs_a_p_i_stats.html#a84e85ad9d94dbe9afd1101388574255d":[2,0,25,1],
+"structjs_account_info.html":[2,0,28],
+"structjs_account_info.html#a1237c3f19a42a3203825971b429312e9":[2,0,28,3],
+"structjs_account_info.html#a17317abf03effdcdedc2003fca8adc71":[2,0,28,2],
+"structjs_account_info.html#a21c14ca283400c684b18e61a534b6724":[2,0,28,8],
+"structjs_account_info.html#a448578d621e878267ad5f1792002a665":[2,0,28,0],
+"structjs_account_info.html#a94ab71c69b7883c2731ae8741ddc1e94":[2,0,28,5],
+"structjs_account_info.html#aad93cf4bb6c1fbb09ae8545c03f315a9":[2,0,28,6],
+"structjs_account_info.html#ab654d5c7456bb62df1808deb32a620fc":[2,0,28,7],
+"structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c":[2,0,28,4],
+"structjs_account_info.html#ad1c254c5b8f11f57062a4e2d5fb10ae3":[2,0,28,1],
+"structjs_account_limits.html":[2,0,26],
+"structjs_account_limits.html#a38875d969274b0f0fcefc6b04ce56eb8":[2,0,26,5],
+"structjs_account_limits.html#a4710a10950857a322c2a3ad6f946ded2":[2,0,26,2],
+"structjs_account_limits.html#a4abf1972690c20d73bd314f2059e8013":[2,0,26,4],
+"structjs_account_limits.html#a6169f29101d51d48eed0803b719e6338":[2,0,26,3],
+"structjs_account_limits.html#a6fff014c46739410ecf298b0cf643b30":[2,0,26,1],
+"structjs_account_limits.html#a7bfc63e6f49ce724663ee534c5efdfa4":[2,0,26,0],
+"structjs_account_limits.html#a858edf99ee1c60354bdba4e59293fb6a":[2,0,26,7],
+"structjs_account_limits.html#a8cca06ab72b715c02a6a2c72b59f6a52":[2,0,26,6],
+"structjs_cluster_info.html":[2,0,12],
+"structjs_cluster_info.html#a237a639579def1345e02f1490a510ed5":[2,0,12,3],
+"structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484":[2,0,12,0],
+"structjs_cluster_info.html#a8dfcae3bc348a5b595b509e3f3d3500b":[2,0,12,2],
+"structjs_cluster_info.html#af7d85652b52f56fa1eedce8f45fe6a19":[2,0,12,1],
+"structjs_consumer_config.html":[2,0,17],
+"structjs_consumer_config.html#a046177256938d6a601c629f9fd82f888":[2,0,17,27],
+"structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a":[2,0,17,0],
+"structjs_consumer_config.html#a2f0243899885dc97f304f48ca52b5356":[2,0,17,4],
+"structjs_consumer_config.html#a30d4142bac47ab6dc583c5ee193704e6":[2,0,17,19],
+"structjs_consumer_config.html#a351b388a36ccb7978e6e85a6f4fc0816":[2,0,17,13],
+"structjs_consumer_config.html#a364127e68bf0d3bf13efdc0b416667f4":[2,0,17,3],
+"structjs_consumer_config.html#a36a14d666d99bdade87a5e21a25491d6":[2,0,17,2],
+"structjs_consumer_config.html#a36cf121162cf0b40edf051991d851ee0":[2,0,17,1],
+"structjs_consumer_config.html#a43f40b8eef0074b4146fb945b4645584":[2,0,17,14],
+"structjs_consumer_config.html#a484c64b6c54f6f758f54315470ed20d0":[2,0,17,17],
+"structjs_consumer_config.html#a4e86deefe08854b9a82b4908397aad32":[2,0,17,20],
+"structjs_consumer_config.html#a651a94b9b78668dde830dc7869610e67":[2,0,17,7],
+"structjs_consumer_config.html#a74a026cdd92c538bcf84297f4468bb21":[2,0,17,22]
 };
