@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()']]],
+  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
   ['nats_2eh_1',['nats.h',['../nats_8h.html',1,'']]],
   ['nats_5faddress_5fmissing_2',['NATS_ADDRESS_MISSING',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ae1d2c1366dbed428f6589f057acc507d',1,'status.h']]],
   ['nats_5fcheckcompatibility_3',['nats_CheckCompatibility',['../group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e',1,'nats.h']]],
@@ -177,78 +177,84 @@ var searchData=
   ['natsoptions_5fseteventloop_174',['natsOptions_SetEventLoop',['../group__opts_group.html#gab09491bad908dedcb323c780280733ff',1,'nats.h']]],
   ['natsoptions_5fsetexpectedhostname_175',['natsOptions_SetExpectedHostname',['../group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851',1,'nats.h']]],
   ['natsoptions_5fsetfailrequestsondisconnect_176',['natsOptions_SetFailRequestsOnDisconnect',['../group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79',1,'nats.h']]],
-  ['natsoptions_5fsetiobufsize_177',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
-  ['natsoptions_5fsetlameduckmodecb_178',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
-  ['natsoptions_5fsetmaxpendingmsgs_179',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
-  ['natsoptions_5fsetmaxpingsout_180',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
-  ['natsoptions_5fsetmaxreconnect_181',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
-  ['natsoptions_5fsetname_182',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
-  ['natsoptions_5fsetnkey_183',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
-  ['natsoptions_5fsetnkeyfromseed_184',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
-  ['natsoptions_5fsetnoecho_185',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
-  ['natsoptions_5fsetnorandomize_186',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
-  ['natsoptions_5fsetpedantic_187',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
-  ['natsoptions_5fsetpinginterval_188',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectbufsize_189',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectedcb_190',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectjitter_191',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectwait_192',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
-  ['natsoptions_5fsetretryonfailedconnect_193',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
-  ['natsoptions_5fsetsecure_194',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
-  ['natsoptions_5fsetsendasap_195',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
-  ['natsoptions_5fsetservers_196',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
-  ['natsoptions_5fsettimeout_197',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
-  ['natsoptions_5fsettoken_198',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
-  ['natsoptions_5fsettokenhandler_199',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
-  ['natsoptions_5fseturl_200',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
-  ['natsoptions_5fsetusercredentialscallbacks_201',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
-  ['natsoptions_5fsetusercredentialsfromfiles_202',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
-  ['natsoptions_5fsetuserinfo_203',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
-  ['natsoptions_5fsetverbose_204',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
-  ['natsoptions_5fsetwritedeadline_205',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
-  ['natsoptions_5fskipserververification_206',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
-  ['natsoptions_5fuseglobalmessagedelivery_207',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
-  ['natsoptions_5fuseoldrequeststyle_208',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
-  ['natssignaturehandler_209',['natsSignatureHandler',['../group__callbacks_group.html#gab786ffd670c86de0563559351305080b',1,'nats.h']]],
-  ['natssock_210',['natsSock',['../nats_8h.html#af798865ac824e5959987de0fe8d07383',1,'nats.h']]],
-  ['natsstatistics_211',['natsStatistics',['../group__types_group.html#ga57a4b8c7109e2773878655722ce028aa',1,'nats.h']]],
-  ['natsstatistics_5fcreate_212',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
-  ['natsstatistics_5fdestroy_213',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
-  ['natsstatistics_5fgetcounts_214',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
-  ['natsstatus_215',['natsStatus',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80',1,'status.h']]],
-  ['natsstatus_5fgettext_216',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
-  ['natssubscription_217',['natsSubscription',['../group__types_group.html#ga87158ec63b4f90f69e20451624ea01d8',1,'nats.h']]],
-  ['natssubscription_5fautounsubscribe_218',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
-  ['natssubscription_5fclearmaxpending_219',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
-  ['natssubscription_5fdestroy_220',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
-  ['natssubscription_5fdrain_221',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
-  ['natssubscription_5fdraincompletionstatus_222',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
-  ['natssubscription_5fdraintimeout_223',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
-  ['natssubscription_5ffetch_224',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
-  ['natssubscription_5fgetconsumerinfo_225',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
-  ['natssubscription_5fgetdelivered_226',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
-  ['natssubscription_5fgetdropped_227',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
-  ['natssubscription_5fgetmaxpending_228',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
-  ['natssubscription_5fgetpending_229',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
-  ['natssubscription_5fgetpendinglimits_230',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
-  ['natssubscription_5fgetsequencemismatch_231',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
-  ['natssubscription_5fgetstats_232',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
-  ['natssubscription_5fisvalid_233',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
-  ['natssubscription_5fnextmsg_234',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
-  ['natssubscription_5fnodeliverydelay_235',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
-  ['natssubscription_5fqueuedmsgs_236',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
-  ['natssubscription_5fsetoncompletecb_237',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
-  ['natssubscription_5fsetpendinglimits_238',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
-  ['natssubscription_5funsubscribe_239',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
-  ['natssubscription_5fwaitfordraincompletion_240',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]],
-  ['natstokenhandler_241',['natsTokenHandler',['../group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499',1,'nats.h']]],
-  ['natsuserjwthandler_242',['natsUserJWTHandler',['../group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b',1,'nats.h']]],
-  ['noack_243',['NoAck',['../structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609',1,'jsStreamConfig']]],
-  ['numackpending_244',['NumAckPending',['../structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50',1,'jsConsumerInfo']]],
-  ['numdeleted_245',['NumDeleted',['../structjs_stream_state.html#acbec2f01830b56cb4c0bf54ae5170e51',1,'jsStreamState']]],
-  ['numdelivered_246',['NumDelivered',['../structjs_msg_meta_data.html#a9a50965fac061a9728b160702d3f56ff',1,'jsMsgMetaData']]],
-  ['numpending_247',['NumPending',['../structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b',1,'jsConsumerInfo::NumPending()'],['../structjs_msg_meta_data.html#a02f1bbd37e9650ed6bfda0210f038e30',1,'jsMsgMetaData::NumPending()']]],
-  ['numredelivered_248',['NumRedelivered',['../structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001',1,'jsConsumerInfo']]],
-  ['numsubjects_249',['NumSubjects',['../structjs_stream_state.html#aaa43db17641826e7c6ecc1954f641960',1,'jsStreamState']]],
-  ['numwaiting_250',['NumWaiting',['../structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0',1,'jsConsumerInfo']]]
+  ['natsoptions_5fsetignorediscoveredservers_177',['natsOptions_SetIgnoreDiscoveredServers',['../group__opts_group.html#ga7e4172084520708b8c9f28e73174461c',1,'nats.h']]],
+  ['natsoptions_5fsetiobufsize_178',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
+  ['natsoptions_5fsetlameduckmodecb_179',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
+  ['natsoptions_5fsetmaxpendingmsgs_180',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
+  ['natsoptions_5fsetmaxpingsout_181',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
+  ['natsoptions_5fsetmaxreconnect_182',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
+  ['natsoptions_5fsetname_183',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
+  ['natsoptions_5fsetnkey_184',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
+  ['natsoptions_5fsetnkeyfromseed_185',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
+  ['natsoptions_5fsetnoecho_186',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
+  ['natsoptions_5fsetnorandomize_187',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
+  ['natsoptions_5fsetpedantic_188',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
+  ['natsoptions_5fsetpinginterval_189',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectbufsize_190',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectedcb_191',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectjitter_192',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectwait_193',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
+  ['natsoptions_5fsetretryonfailedconnect_194',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
+  ['natsoptions_5fsetsecure_195',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
+  ['natsoptions_5fsetsendasap_196',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
+  ['natsoptions_5fsetservers_197',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
+  ['natsoptions_5fsettimeout_198',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
+  ['natsoptions_5fsettoken_199',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
+  ['natsoptions_5fsettokenhandler_200',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
+  ['natsoptions_5fseturl_201',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
+  ['natsoptions_5fsetusercredentialscallbacks_202',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
+  ['natsoptions_5fsetusercredentialsfromfiles_203',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
+  ['natsoptions_5fsetuserinfo_204',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
+  ['natsoptions_5fsetverbose_205',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
+  ['natsoptions_5fsetwritedeadline_206',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
+  ['natsoptions_5fskipserververification_207',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
+  ['natsoptions_5fuseglobalmessagedelivery_208',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
+  ['natsoptions_5fuseoldrequeststyle_209',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
+  ['natssignaturehandler_210',['natsSignatureHandler',['../group__callbacks_group.html#gab786ffd670c86de0563559351305080b',1,'nats.h']]],
+  ['natssock_211',['natsSock',['../nats_8h.html#af798865ac824e5959987de0fe8d07383',1,'nats.h']]],
+  ['natsstatistics_212',['natsStatistics',['../group__types_group.html#ga57a4b8c7109e2773878655722ce028aa',1,'nats.h']]],
+  ['natsstatistics_5fcreate_213',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
+  ['natsstatistics_5fdestroy_214',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
+  ['natsstatistics_5fgetcounts_215',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
+  ['natsstatus_216',['natsStatus',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80',1,'status.h']]],
+  ['natsstatus_5fgettext_217',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
+  ['natssubscription_218',['natsSubscription',['../group__types_group.html#ga87158ec63b4f90f69e20451624ea01d8',1,'nats.h']]],
+  ['natssubscription_5fautounsubscribe_219',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
+  ['natssubscription_5fclearmaxpending_220',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
+  ['natssubscription_5fdestroy_221',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
+  ['natssubscription_5fdrain_222',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
+  ['natssubscription_5fdraincompletionstatus_223',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
+  ['natssubscription_5fdraintimeout_224',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
+  ['natssubscription_5ffetch_225',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
+  ['natssubscription_5ffetchrequest_226',['natsSubscription_FetchRequest',['../group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed',1,'nats.h']]],
+  ['natssubscription_5fgetconsumerinfo_227',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
+  ['natssubscription_5fgetdelivered_228',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
+  ['natssubscription_5fgetdropped_229',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
+  ['natssubscription_5fgetid_230',['natsSubscription_GetID',['../group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20',1,'nats.h']]],
+  ['natssubscription_5fgetmaxpending_231',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
+  ['natssubscription_5fgetpending_232',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
+  ['natssubscription_5fgetpendinglimits_233',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
+  ['natssubscription_5fgetsequencemismatch_234',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
+  ['natssubscription_5fgetstats_235',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
+  ['natssubscription_5fgetsubject_236',['natsSubscription_GetSubject',['../group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432',1,'nats.h']]],
+  ['natssubscription_5fisvalid_237',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
+  ['natssubscription_5fnextmsg_238',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
+  ['natssubscription_5fnodeliverydelay_239',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
+  ['natssubscription_5fqueuedmsgs_240',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
+  ['natssubscription_5fsetoncompletecb_241',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
+  ['natssubscription_5fsetpendinglimits_242',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
+  ['natssubscription_5funsubscribe_243',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
+  ['natssubscription_5fwaitfordraincompletion_244',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]],
+  ['natstokenhandler_245',['natsTokenHandler',['../group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499',1,'nats.h']]],
+  ['natsuserjwthandler_246',['natsUserJWTHandler',['../group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b',1,'nats.h']]],
+  ['nextbysubject_247',['NextBySubject',['../structjs_direct_get_msg_options.html#a16ce7908a3d1690b8ae8bc22350ac238',1,'jsDirectGetMsgOptions']]],
+  ['noack_248',['NoAck',['../structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609',1,'jsStreamConfig']]],
+  ['nowait_249',['NoWait',['../structjs_fetch_request.html#ae251eebb1998a39fe3b898302b58293d',1,'jsFetchRequest']]],
+  ['numackpending_250',['NumAckPending',['../structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50',1,'jsConsumerInfo']]],
+  ['numdeleted_251',['NumDeleted',['../structjs_stream_state.html#acbec2f01830b56cb4c0bf54ae5170e51',1,'jsStreamState']]],
+  ['numdelivered_252',['NumDelivered',['../structjs_msg_meta_data.html#a9a50965fac061a9728b160702d3f56ff',1,'jsMsgMetaData']]],
+  ['numpending_253',['NumPending',['../structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b',1,'jsConsumerInfo::NumPending()'],['../structjs_msg_meta_data.html#a02f1bbd37e9650ed6bfda0210f038e30',1,'jsMsgMetaData::NumPending()']]],
+  ['numredelivered_254',['NumRedelivered',['../structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001',1,'jsConsumerInfo']]],
+  ['numsubjects_255',['NumSubjects',['../structjs_stream_state.html#aaa43db17641826e7c6ecc1954f641960',1,'jsStreamState']]],
+  ['numwaiting_256',['NumWaiting',['../structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0',1,'jsConsumerInfo']]]
 ];
