@@ -114,63 +114,67 @@ var searchData=
   ['natsoptions_5fseteventloop_111',['natsOptions_SetEventLoop',['../group__opts_group.html#gab09491bad908dedcb323c780280733ff',1,'nats.h']]],
   ['natsoptions_5fsetexpectedhostname_112',['natsOptions_SetExpectedHostname',['../group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851',1,'nats.h']]],
   ['natsoptions_5fsetfailrequestsondisconnect_113',['natsOptions_SetFailRequestsOnDisconnect',['../group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79',1,'nats.h']]],
-  ['natsoptions_5fsetiobufsize_114',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
-  ['natsoptions_5fsetlameduckmodecb_115',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
-  ['natsoptions_5fsetmaxpendingmsgs_116',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
-  ['natsoptions_5fsetmaxpingsout_117',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
-  ['natsoptions_5fsetmaxreconnect_118',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
-  ['natsoptions_5fsetname_119',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
-  ['natsoptions_5fsetnkey_120',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
-  ['natsoptions_5fsetnkeyfromseed_121',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
-  ['natsoptions_5fsetnoecho_122',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
-  ['natsoptions_5fsetnorandomize_123',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
-  ['natsoptions_5fsetpedantic_124',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
-  ['natsoptions_5fsetpinginterval_125',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectbufsize_126',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectedcb_127',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectjitter_128',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
-  ['natsoptions_5fsetreconnectwait_129',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
-  ['natsoptions_5fsetretryonfailedconnect_130',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
-  ['natsoptions_5fsetsecure_131',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
-  ['natsoptions_5fsetsendasap_132',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
-  ['natsoptions_5fsetservers_133',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
-  ['natsoptions_5fsettimeout_134',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
-  ['natsoptions_5fsettoken_135',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
-  ['natsoptions_5fsettokenhandler_136',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
-  ['natsoptions_5fseturl_137',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
-  ['natsoptions_5fsetusercredentialscallbacks_138',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
-  ['natsoptions_5fsetusercredentialsfromfiles_139',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
-  ['natsoptions_5fsetuserinfo_140',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
-  ['natsoptions_5fsetverbose_141',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
-  ['natsoptions_5fsetwritedeadline_142',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
-  ['natsoptions_5fskipserververification_143',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
-  ['natsoptions_5fuseglobalmessagedelivery_144',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
-  ['natsoptions_5fuseoldrequeststyle_145',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
-  ['natsstatistics_5fcreate_146',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
-  ['natsstatistics_5fdestroy_147',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
-  ['natsstatistics_5fgetcounts_148',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
-  ['natsstatus_5fgettext_149',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
-  ['natssubscription_5fautounsubscribe_150',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
-  ['natssubscription_5fclearmaxpending_151',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
-  ['natssubscription_5fdestroy_152',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
-  ['natssubscription_5fdrain_153',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
-  ['natssubscription_5fdraincompletionstatus_154',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
-  ['natssubscription_5fdraintimeout_155',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
-  ['natssubscription_5ffetch_156',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
-  ['natssubscription_5fgetconsumerinfo_157',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
-  ['natssubscription_5fgetdelivered_158',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
-  ['natssubscription_5fgetdropped_159',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
-  ['natssubscription_5fgetmaxpending_160',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
-  ['natssubscription_5fgetpending_161',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
-  ['natssubscription_5fgetpendinglimits_162',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
-  ['natssubscription_5fgetsequencemismatch_163',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
-  ['natssubscription_5fgetstats_164',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
-  ['natssubscription_5fisvalid_165',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
-  ['natssubscription_5fnextmsg_166',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
-  ['natssubscription_5fnodeliverydelay_167',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
-  ['natssubscription_5fqueuedmsgs_168',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
-  ['natssubscription_5fsetoncompletecb_169',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
-  ['natssubscription_5fsetpendinglimits_170',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
-  ['natssubscription_5funsubscribe_171',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
-  ['natssubscription_5fwaitfordraincompletion_172',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]]
+  ['natsoptions_5fsetignorediscoveredservers_114',['natsOptions_SetIgnoreDiscoveredServers',['../group__opts_group.html#ga7e4172084520708b8c9f28e73174461c',1,'nats.h']]],
+  ['natsoptions_5fsetiobufsize_115',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
+  ['natsoptions_5fsetlameduckmodecb_116',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
+  ['natsoptions_5fsetmaxpendingmsgs_117',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
+  ['natsoptions_5fsetmaxpingsout_118',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
+  ['natsoptions_5fsetmaxreconnect_119',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
+  ['natsoptions_5fsetname_120',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
+  ['natsoptions_5fsetnkey_121',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
+  ['natsoptions_5fsetnkeyfromseed_122',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
+  ['natsoptions_5fsetnoecho_123',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
+  ['natsoptions_5fsetnorandomize_124',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
+  ['natsoptions_5fsetpedantic_125',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
+  ['natsoptions_5fsetpinginterval_126',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectbufsize_127',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectedcb_128',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectjitter_129',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
+  ['natsoptions_5fsetreconnectwait_130',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
+  ['natsoptions_5fsetretryonfailedconnect_131',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
+  ['natsoptions_5fsetsecure_132',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
+  ['natsoptions_5fsetsendasap_133',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
+  ['natsoptions_5fsetservers_134',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
+  ['natsoptions_5fsettimeout_135',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
+  ['natsoptions_5fsettoken_136',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
+  ['natsoptions_5fsettokenhandler_137',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
+  ['natsoptions_5fseturl_138',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
+  ['natsoptions_5fsetusercredentialscallbacks_139',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
+  ['natsoptions_5fsetusercredentialsfromfiles_140',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
+  ['natsoptions_5fsetuserinfo_141',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
+  ['natsoptions_5fsetverbose_142',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
+  ['natsoptions_5fsetwritedeadline_143',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
+  ['natsoptions_5fskipserververification_144',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
+  ['natsoptions_5fuseglobalmessagedelivery_145',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
+  ['natsoptions_5fuseoldrequeststyle_146',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
+  ['natsstatistics_5fcreate_147',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
+  ['natsstatistics_5fdestroy_148',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
+  ['natsstatistics_5fgetcounts_149',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
+  ['natsstatus_5fgettext_150',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
+  ['natssubscription_5fautounsubscribe_151',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
+  ['natssubscription_5fclearmaxpending_152',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
+  ['natssubscription_5fdestroy_153',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
+  ['natssubscription_5fdrain_154',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
+  ['natssubscription_5fdraincompletionstatus_155',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
+  ['natssubscription_5fdraintimeout_156',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
+  ['natssubscription_5ffetch_157',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
+  ['natssubscription_5ffetchrequest_158',['natsSubscription_FetchRequest',['../group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed',1,'nats.h']]],
+  ['natssubscription_5fgetconsumerinfo_159',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
+  ['natssubscription_5fgetdelivered_160',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
+  ['natssubscription_5fgetdropped_161',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
+  ['natssubscription_5fgetid_162',['natsSubscription_GetID',['../group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20',1,'nats.h']]],
+  ['natssubscription_5fgetmaxpending_163',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
+  ['natssubscription_5fgetpending_164',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
+  ['natssubscription_5fgetpendinglimits_165',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
+  ['natssubscription_5fgetsequencemismatch_166',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
+  ['natssubscription_5fgetstats_167',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
+  ['natssubscription_5fgetsubject_168',['natsSubscription_GetSubject',['../group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432',1,'nats.h']]],
+  ['natssubscription_5fisvalid_169',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
+  ['natssubscription_5fnextmsg_170',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
+  ['natssubscription_5fnodeliverydelay_171',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
+  ['natssubscription_5fqueuedmsgs_172',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
+  ['natssubscription_5fsetoncompletecb_173',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
+  ['natssubscription_5fsetpendinglimits_174',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
+  ['natssubscription_5funsubscribe_175',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
+  ['natssubscription_5fwaitfordraincompletion_176',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]]
 ];
