@@ -12,9 +12,11 @@ var searchData=
   ['denydelete_9',['DenyDelete',['../structjs_stream_config.html#af2d42dd29b9a35257937aeeb53c9f287',1,'jsStreamConfig']]],
   ['denypurge_10',['DenyPurge',['../structjs_stream_config.html#a575ffbaa85b0300032963296b090583a',1,'jsStreamConfig']]],
   ['description_11',['Description',['../structjs_stream_config.html#a4f9f422d2e9e7389860291ab19bd7f10',1,'jsStreamConfig::Description()'],['../structjs_consumer_config.html#a36a14d666d99bdade87a5e21a25491d6',1,'jsConsumerConfig::Description()'],['../structkv_config.html#a941e9cad2bab67f093bf4d9567b4749a',1,'kvConfig::Description()']]],
-  ['discard_12',['Discard',['../structjs_stream_config.html#a0b44ea5251ef20bf5b5658bcfbea832d',1,'jsStreamConfig']]],
-  ['domain_13',['Domain',['../structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c',1,'jsAccountInfo::Domain()'],['../structjs_msg_meta_data.html#a388e38ccea591181436d199dc7c2f8ea',1,'jsMsgMetaData::Domain()'],['../structjs_pub_ack.html#a0b73200c0b035db3c9c96421706d51b0',1,'jsPubAck::Domain()'],['../structjs_options.html#ae4df6c9c01c0ea9ab0e6d5a6ec8af74e',1,'jsOptions::Domain()']]],
-  ['duplicate_14',['Duplicate',['../structjs_pub_ack.html#a0381a49ff62e8fac7a52cad6a5eb7243',1,'jsPubAck']]],
-  ['duplicates_15',['Duplicates',['../structjs_stream_config.html#a9e0ff10273d0182f885615b4f7d1cc20',1,'jsStreamConfig']]],
-  ['durable_16',['Durable',['../structjs_consumer_config.html#a36cf121162cf0b40edf051991d851ee0',1,'jsConsumerConfig']]]
+  ['destination_12',['Destination',['../structjs_re_publish.html#a662b2e57d237b171b2b61509f7e1023a',1,'jsRePublish']]],
+  ['discard_13',['Discard',['../structjs_stream_config.html#a0b44ea5251ef20bf5b5658bcfbea832d',1,'jsStreamConfig']]],
+  ['discardnewpersubject_14',['DiscardNewPerSubject',['../structjs_stream_config.html#a3fb7d5e1a09829fe742749da880afe4a',1,'jsStreamConfig']]],
+  ['domain_15',['Domain',['../structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c',1,'jsAccountInfo::Domain()'],['../structjs_msg_meta_data.html#a388e38ccea591181436d199dc7c2f8ea',1,'jsMsgMetaData::Domain()'],['../structjs_pub_ack.html#a0b73200c0b035db3c9c96421706d51b0',1,'jsPubAck::Domain()'],['../structjs_options.html#ae4df6c9c01c0ea9ab0e6d5a6ec8af74e',1,'jsOptions::Domain()']]],
+  ['duplicate_16',['Duplicate',['../structjs_pub_ack.html#a0381a49ff62e8fac7a52cad6a5eb7243',1,'jsPubAck']]],
+  ['duplicates_17',['Duplicates',['../structjs_stream_config.html#a9e0ff10273d0182f885615b4f7d1cc20',1,'jsStreamConfig']]],
+  ['durable_18',['Durable',['../structjs_consumer_config.html#a36cf121162cf0b40edf051991d851ee0',1,'jsConsumerConfig']]]
 ];
