@@ -6,5 +6,7 @@ var structjs_account_info =
     [ "Consumers", "structjs_account_info.html#a1237c3f19a42a3203825971b429312e9", null ],
     [ "Domain", "structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c", null ],
     [ "API", "structjs_account_info.html#a94ab71c69b7883c2731ae8741ddc1e94", null ],
-    [ "Limits", "structjs_account_info.html#aad93cf4bb6c1fbb09ae8545c03f315a9", null ]
+    [ "Limits", "structjs_account_info.html#aad93cf4bb6c1fbb09ae8545c03f315a9", null ],
+    [ "Tiers", "structjs_account_info.html#ab654d5c7456bb62df1808deb32a620fc", null ],
+    [ "TiersLen", "structjs_account_info.html#a21c14ca283400c684b18e61a534b6724", null ]
 ];
\ No newline at end of file
