@@ -60,6 +60,12 @@ extern const int64_t    jsDefaultRequestWait;
 #define jsErrOrderedConsNoQueue             "queue can not be set for an ordered consumer"
 #define jsErrOrderedConsNoBind              "can not bind existing consumer for an ordered consumer"
 #define jsErrOrderedConsNoPullMode          "can not use pull mode for an ordered consumer"
+#define jsErrStreamConfigRequired           "stream configuration required"
+#define jsErrInvalidStreamName              "invalid stream name"
+#define jsErrConsumerConfigRequired         "consumer configuration required"
+#define jsErrInvalidDurableName             "invalid durable name"
+#define jsErrInvalidConsumerName            "invalid consumer name"
+#define jsErrConcurrentFetchNotAllowed      "concurrent fetch request not allowed"
 
 #define jsCtrlHeartbeat     (1)
 #define jsCtrlFlowControl   (2)
@@ -121,6 +127,12 @@ extern const int64_t    jsDefaultRequestWait;
 // jsApiDurableCreateT is used to create durable consumers.
 #define jsApiDurableCreateT "%.*s.CONSUMER.DURABLE.CREATE.%s.%s"
 
+// jsApiConsumerCreateExT is used to create a named consumer.
+#define jsApiConsumerCreateExT "%.*s.CONSUMER.CREATE.%s.%s"
+
+// jsApiConsumerCreateExWithFilterT is used to create a named consumer with a filter subject.
+#define jsApiConsumerCreateExWithFilterT "%.*s.CONSUMER.CREATE.%s.%s.%s"
+
 // jsApiConsumerInfoT is used to get information about consumers.
 #define jsApiConsumerInfoT "%.*s.CONSUMER.INFO.%s.%s"
 
@@ -139,6 +151,24 @@ extern const int64_t    jsDefaultRequestWait;
 // jsApiMsgGetT is the endpoint to get a message, either by sequence or last per subject.
 #define jsApiMsgGetT "%.*s.STREAM.MSG.GET.%s"
 
+// jsApiMsgGetT is the endpoint to get a message, either by sequence or last per subject.
+#define jsApiDirectMsgGetT "%.*s.DIRECT.GET.%s"
+
+// jsApiDirectMsgGetLastBySubjectT is the endpoint to perform a direct get of a message by subject.
+#define jsApiDirectMsgGetLastBySubjectT "%.*s.DIRECT.GET.%s.%s"
+
+// jsApiStreamListT is the endpoint to get the list of stream infos.
+#define jsApiStreamListT "%.*s.STREAM.LIST"
+
+// jsApiStreamNamesT is the endpoint to get the list of stream names.
+#define jsApiStreamNamesT "%.*s.STREAM.NAMES"
+
+// jsApiConsumerListT is the endpoint to get the list of consumers for a stream.
+#define jsApiConsumerListT "%.*s.CONSUMER.LIST.%s"
+
+// jsApiConsumerNamesT is the endpoint to get the list of consumer names for a stream.
+#define jsApiConsumerNamesT "%.*s.CONSUMER.NAMES.%s"
+
 // Creates a subject based on the option's prefix, the subject format and its values.
 #define js_apiSubj(s, o, f, ...) (nats_asprintf((s), (f), (o)->Prefix, __VA_ARGS__) < 0 ? NATS_NO_MEMORY : NATS_OK)
 
@@ -207,7 +237,7 @@ void
 js_cleanStreamState(jsStreamState *state);
 
 natsStatus
-js_checkDurName(const char *dur);
+js_checkConsName(const char *cons, bool isDurable);
 
 natsStatus
 js_getMetaData(const char *reply,
@@ -226,3 +256,12 @@ js_retain(jsCtx *js);
 
 void
 js_release(jsCtx *js);
+
+natsStatus
+js_directGetMsgToJSMsg(const char *stream, natsMsg *msg);
+
+natsStatus
+js_cloneConsumerConfig(jsConsumerConfig *org, jsConsumerConfig **clone);
+
+void
+js_destroyConsumerConfig(jsConsumerConfig *cc);
