@@ -244,6 +244,7 @@ js_CreateKeyValue(kvStore **new_kv, jsCtx *js, kvConfig *cfg)
     int64_t         replicas= 1;
     kvStore         *kv     = NULL;
     char            *subject= NULL;
+    jsStreamInfo    *si     = NULL;
     jsStreamConfig  sc;
 
     if ((new_kv == NULL) || (js == NULL) || (cfg == NULL))
@@ -287,15 +288,18 @@ js_CreateKeyValue(kvStore **new_kv, jsCtx *js, kvConfig *cfg)
         sc.Replicas = replicas;
         sc.AllowRollup = true;
         sc.DenyDelete = true;
+        sc.AllowDirect = true;
+        sc.RePublish = cfg->RePublish;
 
         // If connecting to a v2.7.2+, create with discard new policy
         if (natsConn_srvVersionAtLeast(kv->js->nc, 2, 7, 2))
             sc.Discard = js_DiscardNew;
 
-        s = js_AddStream(NULL, js, &sc, NULL, &jerr);
+        s = js_AddStream(&si, js, &sc, NULL, &jerr);
         if ((s != NATS_OK) && (jerr == JSStreamNameExistErr))
         {
-            jsStreamInfo *si = NULL;
+            jsStreamInfo_Destroy(si);
+            si = NULL;
 
             nats_clearLastError();
             s = js_GetStreamInfo(&si, js, sc.Name, NULL, NULL);
@@ -303,13 +307,22 @@ js_CreateKeyValue(kvStore **new_kv, jsCtx *js, kvConfig *cfg)
             {
                 si->Config->Discard = sc.Discard;
                 if (_sameStreamCfg(si->Config, &sc))
-                    s = js_UpdateStream(NULL, js, &sc, NULL, NULL);
+                {
+                    jsStreamInfo_Destroy(si);
+                    si = NULL;
+                    s = js_UpdateStream(&si, js, &sc, NULL, NULL);
+                }
                 else
                     s = nats_setError(NATS_ERR, "%s",
                         "Existing configuration is different");
             }
-            jsStreamInfo_Destroy(si);
         }
+        if (s == NATS_OK)
+        {
+            // If the stream allow direct get message calls, then we will do so.
+            kv->useDirect = si->Config->AllowDirect;
+        }
+        jsStreamInfo_Destroy(si);
     }
     if (s == NATS_OK)
         *new_kv = kv;
@@ -338,6 +351,9 @@ js_KeyValue(kvStore **new_kv, jsCtx *js, const char *bucket)
     s = js_GetStreamInfo(&si, js, kv->stream, NULL, NULL);
     if (s == NATS_OK)
     {
+        // If the stream allow direct get message calls, then we will do so.
+        kv->useDirect = si->Config->AllowDirect;
+
         // Do some quick sanity checks that this is a correctly formed stream for KV.
         // Max msgs per subject should be > 0.
         if (si->Config->MaxMsgsPerSubject < 1)
@@ -456,6 +472,7 @@ _getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key, uint
     natsMsg     *msg    = NULL;
     kvEntry     *e      = NULL;
     DEFINE_BUF_FOR_SUBJECT;
+    jsDirectGetMsgOptions dgo;
 
     *new_entry = NULL;
     *deleted   = false;
@@ -464,15 +481,29 @@ _getEntry(kvEntry **new_entry, bool *deleted, kvStore *kv, const char *key, uint
         return nats_setError(NATS_INVALID_ARG, "%s", kvErrInvalidKey);
 
     BUILD_SUBJECT(KEY_NAME_ONLY);
-    if (revision == 0)
+
+    if (kv->useDirect)
+    {
+        jsDirectGetMsgOptions_Init(&dgo);
+        if (revision == 0)
+            dgo.LastBySubject = natsBuf_Data(&buf);
+        else
+            dgo.Sequence = revision;
+
+        IFOK(s, js_DirectGetMsg(&msg, kv->js, kv->stream, NULL, &dgo));
+    }
+    else if (revision == 0)
     {
         IFOK(s, js_GetLastMsg(&msg, kv->js, kv->stream, natsBuf_Data(&buf), NULL, NULL));
     }
     else
     {
         IFOK(s, js_GetMsg(&msg, kv->js, kv->stream, revision, NULL, NULL));
-        IFOK(s, (strcmp(natsMsg_GetSubject(msg), natsBuf_Data(&buf)) == 0 ? NATS_OK : NATS_NOT_FOUND));
     }
+    // If a sequence was provided, just make sure that the retrieved
+    // message subject matches the request.
+    if (revision != 0)
+        IFOK(s, (strcmp(natsMsg_GetSubject(msg), natsBuf_Data(&buf)) == 0 ? NATS_OK : NATS_NOT_FOUND));
     IFOK(s, _createEntry(&e, kv, &msg));
     if (s == NATS_OK)
         e->op = _getKVOp(e->msg);
@@ -998,6 +1029,7 @@ kvStore_Watch(kvWatcher **new_watcher, kvStore *kv, const char *key, kvWatchOpti
                 w->ignoreDel = true;
         }
         s = js_SubscribeSync(&(w->sub), kv->js, natsBuf_Data(&buf), NULL, &so, NULL);
+        IFOK(s, natsSubscription_SetPendingLimits(w->sub, -1, -1));
         if (s == NATS_OK)
         {
             natsSubscription *sub = w->sub;
@@ -1042,7 +1074,7 @@ kvStore_Keys(kvKeysList *list, kvStore *kv, kvWatchOptions *opts)
         return nats_setDefaultError(NATS_INVALID_ARG);
 
     list->Keys = NULL;
-    *(int*)&(list->Count) = 0;
+    list->Count = 0;
 
     kvWatchOptions_Init(&o);
     if (opts != NULL)
@@ -1085,7 +1117,7 @@ kvStore_Keys(kvKeysList *list, kvStore *kv, kvWatchOptions *opts)
     // Set the list's Count to `count`, not `n` since `count`
     // will reflect the actual number of keys that have been
     // properly strdup'ed.
-    *(int*)&(list->Count) = count;
+    list->Count = count;
 
     // If there was a failure (especially when strdup'ing) keys,
     // this will do the proper cleanup and re-initialize the list.
@@ -1107,7 +1139,7 @@ kvKeysList_Destroy(kvKeysList *list)
         NATS_FREE(list->Keys[i]);
     NATS_FREE(list->Keys);
     list->Keys = NULL;
-    *(int*)&(list->Count) = 0;
+    list->Count = 0;
 }
 
 natsStatus
@@ -1128,7 +1160,7 @@ kvStore_History(kvEntryList *list, kvStore *kv, const char *key, kvWatchOptions
         return nats_setDefaultError(NATS_INVALID_ARG);
 
     list->Entries = NULL;
-    *(int*)&(list->Count) = 0;
+    list->Count = 0;
 
     kvWatchOptions_Init(&o);
     if (opts != NULL)
@@ -1153,7 +1185,7 @@ kvStore_History(kvEntryList *list, kvStore *kv, const char *key, kvWatchOptions
         if (list->Entries == NULL)
             s = nats_setDefaultError(NATS_NO_MEMORY);
         else
-            *(int*)&(list->Count) = n;
+            list->Count = n;
     }
     // Transfer entries to the array (on success), or destroy
     // the entries if there was an error.
@@ -1187,7 +1219,7 @@ kvEntryList_Destroy(kvEntryList *list)
         kvEntry_Destroy(list->Entries[i]);
     NATS_FREE(list->Entries);
     list->Entries = NULL;
-    *(int*)&(list->Count) = 0;
+    list->Count = 0;
 }
 
 natsStatus
