@@ -102,6 +102,8 @@
 
 #define MAX_FRAMES (50)
 
+#define nats_IsStringEmpty(s) ((((s) == NULL) || ((s)[0] == '\0')) ? true : false)
+
 #define DUP_STRING(s, s1, s2) \
         { \
             (s1) = NATS_STRDUP(s2); \
@@ -110,7 +112,7 @@
         }
 
 #define IF_OK_DUP_STRING(s, s1, s2) \
-        if ((s) == NATS_OK) \
+        if (((s) == NATS_OK) && !nats_IsStringEmpty(s2)) \
             DUP_STRING((s), (s1), (s2))
 
 
@@ -233,6 +235,7 @@ struct __natsOptions
 
     natsConnectionHandler   discoveredServersCb;
     void                    *discoveredServersClosure;
+    bool                    ignoreDiscoveredServers;
 
     natsConnectionHandler   connectedCb;
     void                    *connectedCbClosure;
@@ -329,6 +332,14 @@ typedef struct __natsMsgDlvWorker
 
 } natsMsgDlvWorker;
 
+typedef struct __pmInfo
+{
+    char                *subject;
+    int64_t             deadline;
+    struct __pmInfo     *next;
+
+} pmInfo;
+
 struct __jsCtx
 {
     natsMutex		    *mu;
@@ -337,12 +348,16 @@ struct __jsCtx
     int				    refs;
     natsCondition       *cond;
     natsStrHash         *pm;
+    natsTimer           *pmtmr;
+    pmInfo              *pmHead;
+    pmInfo              *pmTail;
     natsSubscription    *rsub;
     char                *rpre;
     int                 rpreLen;
     int                 pacw;
     int64_t             pmcount;
     int                 stalled;
+    bool                closed;
 };
 
 typedef struct __jsSub
@@ -352,6 +367,7 @@ typedef struct __jsSub
     char                *consumer;
     char                *nxtMsgSubj;
     bool                pull;
+    bool                inFetch;
     bool                ordered;
     bool                dc; // delete JS consumer in Unsub()/Drain()
     bool                ackNone;
@@ -365,13 +381,13 @@ typedef struct __jsSub
     uint64_t            pending;
 
     int64_t             hbi;
-    int64_t             active;
+    bool                active;
     natsTimer           *hbTimer;
+    natsMsg             *mhMsg;
 
     char                *cmeta;
     uint64_t            sseq;
     uint64_t            dseq;
-    uint64_t            ldseq;
     // Skip sequence mismatch notification. This is used for
     // async subscriptions to notify the asyn err handler only
     // once. Should the mismatch be resolved, this will be
@@ -384,6 +400,13 @@ typedef struct __jsSub
     // the sequence mismatch report. Should the mismatch be
     // resolved, this will be cleared.
     bool                sm;
+    // These are the mismatch seq info
+    struct mismatch
+    {
+        uint64_t        sseq;
+        uint64_t        dseq;
+        uint64_t        ldseq;
+    } mismatch;
 
     // When in auto-ack mode, we have an internal callback
     // that will call natsMsg_Ack after the user callback returns.
@@ -397,8 +420,8 @@ typedef struct __jsSub
     uint64_t            fciseq;
     char                *fcReply;
 
-    // When reseting an OrderedConsumer, need the original filter subject.
-    char                *fsubj;
+    // When reseting an OrderedConsumer, need the original configuration.
+    jsConsumerConfig    *ocCfg;
 
 } jsSub;
 
@@ -411,6 +434,7 @@ struct __kvStore
     char                *stream;
     char                *pre;
     bool                useJSPrefix;
+    bool                useDirect;
 
 };
 
@@ -860,7 +884,7 @@ natsStatus
 jsSub_trackSequences(jsSub *jsi, const char *reply);
 
 natsStatus
-jsSub_processSequenceMismatch(natsSubscription *sub, natsMutex *mu, natsMsg *msg, bool *sm);
+jsSub_processSequenceMismatch(natsSubscription *sub, natsMsg *msg, bool *sm);
 
 char*
 jsSub_checkForFlowControlResponse(natsSubscription *sub);
@@ -869,10 +893,10 @@ natsStatus
 jsSub_scheduleFlowControlResponse(jsSub *jsi, const char *reply);
 
 natsStatus
-jsSub_checkOrderedMsg(natsSubscription *sub, natsMutex *mu, natsMsg *msg, bool *reset);
+jsSub_checkOrderedMsg(natsSubscription *sub, natsMsg *msg, bool *reset);
 
 natsStatus
-jsSub_resetOrderedConsumer(natsSubscription *sub, natsMutex *mu, uint64_t sseq);
+jsSub_resetOrderedConsumer(natsSubscription *sub, uint64_t sseq);
 
 bool
 natsMsg_isJSCtrl(natsMsg *msg, int *ctrlType);
