@@ -239,7 +239,7 @@ natsSub_deliverMsgs(void *arg)
             sub->msgList.tail = NULL;
 
         sub->msgList.msgs--;
-        sub->msgList.bytes -= msg->dataLen;
+        sub->msgList.bytes -= natsMsg_dataAndHdrLen(msg);
 
         msg->next = NULL;
 
@@ -731,7 +731,7 @@ natsSub_nextMsg(natsMsg **nextMsg, natsSubscription *sub, int64_t timeout, bool
                 sub->msgList.tail = NULL;
 
             sub->msgList.msgs--;
-            sub->msgList.bytes -= msg->dataLen;
+            sub->msgList.bytes -= natsMsg_dataAndHdrLen(msg);
 
             msg->next = NULL;
 
@@ -1124,6 +1124,52 @@ natsSubscription_QueuedMsgs(natsSubscription *sub, uint64_t *queuedMsgs)
     return s;
 }
 
+int64_t
+natsSubscription_GetID(natsSubscription* sub)
+{
+    int64_t id = 0;
+
+    if (sub == NULL)
+        return 0;
+
+    natsSub_Lock(sub);
+
+    if (sub->closed)
+    {
+        natsSub_Unlock(sub);
+        return 0;
+    }
+
+    id = sub->sid;
+
+    natsSub_Unlock(sub);
+
+    return id;
+}
+
+const char*
+natsSubscription_GetSubject(natsSubscription* sub)
+{
+    const char* subject = NULL;
+
+    if (sub == NULL)
+        return NULL;
+
+    natsSub_Lock(sub);
+
+    if (sub->closed)
+    {
+        natsSub_Unlock(sub);
+        return NULL;
+    }
+
+    subject = (const char*)sub->subject;
+
+    natsSub_Unlock(sub);
+
+    return subject;
+}
+
 natsStatus
 natsSubscription_GetPending(natsSubscription *sub, int *msgs, int *bytes)
 {
@@ -1401,6 +1447,16 @@ natsSubscription_Destroy(natsSubscription *sub)
     natsSub_Lock(sub);
 
     doUnsub = !(sub->closed);
+    // If not yet closed but user is closing from message callback but it
+    // happens that auto-unsub was used and the max number was delivered, then
+    // we can suppress the UNSUB protocol.
+    if (doUnsub && (sub->max > 0))
+        doUnsub = sub->delivered < sub->max;
+
+    // For a JetStream subscription, disable the "delete consumer" flag
+    // because we auto-delete only on explicit calls to unsub/drain.
+    if (sub->jsi != NULL)
+        sub->jsi->dc = false;
 
     natsSub_Unlock(sub);
 
