@@ -717,6 +717,13 @@ _jsonGetArray(char **ptr, nats_JSONArray **newArray, int nested)
     {
         p = _jsonTrimSpace(p);
 
+        if ((typ == TYPE_NOT_SET) && (*p == ']'))
+        {
+            array.typ = TYPE_NULL;
+            end = true;
+            break;
+        }
+
         // Initialize the field before parsing.
         memset(&field, 0, sizeof(nats_JSONField));
 
@@ -1284,51 +1291,45 @@ nats_JSONGetObject(nats_JSON *json, const char *fieldName, nats_JSON **value)
 }
 
 natsStatus
-nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
+nats_parseTime(char *orgStr, int64_t *timeUTC)
 {
     natsStatus  s           = NATS_OK;
-    char        *str        = NULL;
     char        *dotPos     = NULL;
     char        utcOff[7]   = {'\0'};
     int64_t     nanosecs    = 0;
     char        *p          = NULL;
-    char        orgStr[35]  = {'\0'};
-    char        timeStr[35] = {'\0'};
+    char        timeStr[42] = {'\0'};
+    char        tmpStr[36]  = {'\0'};
+    char        *str        = NULL;
     char        offSign     = '+';
     int         offHours    = 0;
     int         offMin      = 0;
     int         i, l;
     struct tm   tp;
 
-    s = nats_JSONGetStr(json, fieldName, &str);
-    if ((s == NATS_OK) && (str == NULL))
+    // Check for "0"
+    if (strcmp(orgStr, "0001-01-01T00:00:00Z") == 0)
     {
         *timeUTC = 0;
         return NATS_OK;
     }
-    else if (s != NATS_OK)
-        return NATS_UPDATE_ERR_STACK(s);
 
-    // Check for "0"
-    if (strcmp(str, "0001-01-01T00:00:00Z") == 0)
-    {
-        *timeUTC = 0;
-        goto END;
-    }
-
-    l = (int) strlen(str);
+    l = (int) strlen(orgStr);
     // The smallest date/time should be: "YYYY:MM:DDTHH:MM:SSZ", which is 20
     // while the longest should be: "YYYY:MM:DDTHH:MM:SS.123456789-12:34" which is 35
-    if ((l < 20) || (l > (int) sizeof(timeStr)))
+    if ((l < 20) || (l > (int) (sizeof(tmpStr) - 1)))
     {
         if (l < 20)
-            s = nats_setError(NATS_INVALID_ARG, "time '%s' too small", str);
+            s = nats_setError(NATS_INVALID_ARG, "time '%s' too small", orgStr);
         else
-            s = nats_setError(NATS_INVALID_ARG, "time '%s' too long", str);
-        goto END;
+            s = nats_setError(NATS_INVALID_ARG, "time '%s' too long", orgStr);
+        return NATS_UPDATE_ERR_STACK(s);
     }
 
-    snprintf(orgStr, sizeof(orgStr), "%s", str);
+    // Copy the user provided string in our temporary buffer since we may alter
+    // the string as we parse.
+    snprintf(tmpStr, sizeof(tmpStr), "%s", orgStr);
+    str = (char*) tmpStr;
     memset(&tp, 0, sizeof(struct tm));
 
     // If ends with 'Z', the time is already UTC
@@ -1345,7 +1346,7 @@ nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
         if ((strlen(p) != 6) || ((*p != '+') && (*p != '-')) || (*(p+3) != ':'))
         {
             s = nats_setError(NATS_INVALID_ARG, "time '%s' has invalid UTC offset", orgStr);
-            goto END;
+            return NATS_UPDATE_ERR_STACK(s);
         }
         snprintf(utcOff, sizeof(utcOff), "%s", p);
         // Set end of 'str' to beginning of the offset.
@@ -1366,7 +1367,7 @@ nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
         if (val == -1)
         {
             s = nats_setError(NATS_INVALID_ARG, "time '%s' is invalid", orgStr);
-            goto END;
+            return NATS_UPDATE_ERR_STACK(s);
         }
 
         for (i=0; i<9-l; i++)
@@ -1375,7 +1376,7 @@ nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
         if (val > 999999999)
         {
             s = nats_setError(NATS_INVALID_ARG, "time '%s' second fraction too big", orgStr);
-            goto END;
+            return NATS_UPDATE_ERR_STACK(s);
         }
 
         nanosecs = val;
@@ -1402,7 +1403,7 @@ nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
         if (res == -1)
         {
             s = nats_setError(NATS_ERR, "error parsing time '%s'", orgStr);
-            goto END;
+            return NATS_UPDATE_ERR_STACK(s);
         }
         // Compute the offset
         off = (int64_t) ((offHours * 60 * 60) + (offMin * 60));
@@ -1420,7 +1421,25 @@ nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
     {
         s = nats_setError(NATS_ERR, "error parsing time '%s'", orgStr);
     }
-END:
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+nats_JSONGetTime(nats_JSON *json, const char *fieldName, int64_t *timeUTC)
+{
+    natsStatus  s           = NATS_OK;
+    char        *str        = NULL;
+
+    s = nats_JSONGetStr(json, fieldName, &str);
+    if ((s == NATS_OK) && (str == NULL))
+    {
+        *timeUTC = 0;
+        return NATS_OK;
+    }
+    else if (s != NATS_OK)
+        return NATS_UPDATE_ERR_STACK(s);
+
+    s = nats_parseTime(str, timeUTC);
     NATS_FREE(str);
     return NATS_UPDATE_ERR_STACK(s);
 }
@@ -1442,6 +1461,12 @@ nats_JSONGetArrayField(nats_JSON *json, const char *fieldName, int fieldType, na
         return nats_setError(NATS_INVALID_ARG,
                              "Field '%s' is not an array, it has type: %d",
                              field->name, field->typ);
+    // If empty array, return NULL/OK
+    if (field->value.varr->typ == TYPE_NULL)
+    {
+        *retField = NULL;
+        return NATS_OK;
+    }
     if (fieldType != field->value.varr->typ)
         return nats_setError(NATS_INVALID_ARG,
                              "Asked for field '%s' as an array of type: %d, but it is an array of type: %d",
