@@ -68,8 +68,6 @@ typedef struct
 
 typedef natsStatus (*jsonRangeCB)(void *userInfo, const char *fieldName, nats_JSONField *f);
 
-#define nats_IsStringEmpty(s) (((s == NULL) || (s[0] == '\0')) ? true : false)
-
 #define snprintf_truncate(d, szd, f, ...) if (snprintf((d), (szd), (f), __VA_ARGS__) >= (int) (szd)) { \
     int offset = (int) (szd) - 2;         \
     if (offset > 0) (d)[offset--] = '.';  \
@@ -245,4 +243,7 @@ nats_marshalULong(natsBuffer *buf, bool comma, const char *fieldName, uint64_t u
 bool
 nats_IsSubjectValid(const char *subject, bool wcAllowed);
 
+natsStatus
+nats_parseTime(char *str, int64_t *timeUTC);
+
 #endif /* UTIL_H_ */
